import 'package:darq/darq.dart';
import 'package:test/test.dart';

void main() {
  group('cartesianSelect', () {
    test('two lists', () {
      final list = ['a', 'b'];
      final other = ['c', 'd'];
      final result = list.cartesianSelect(other, (a, b) => '$a,$b');
      expect(result, orderedEquals(['a,c', 'a,d', 'b,c', 'b,d']));
    });

    test('three lists', () {
      final list = ['a', 'b'];
      final l2 = ['c', 'd'];
      final l3 = ['e', 'f'];
      final result = list.cartesianSelect3(
        l2,
        l3,
        (a, b, c) => '$a,$b,$c',
      );
      expect(
        result,
        orderedEquals(
          [
            'a,c,e',
            'a,c,f',
            'a,d,e',
            'a,d,f',
            'b,c,e',
            'b,c,f',
            'b,d,e',
            'b,d,f',
          ],
        ),
      );
    });

    test('four lists', () {
      final list = ['a', 'b'];
      final l2 = ['c', 'd'];
      final l3 = ['e', 'f'];
      final l4 = ['g', 'h'];
      final result = list.cartesianSelect4(
        l2,
        l3,
        l4,
        (a, b, c, d) => '$a,$b,$c,$d',
      );
      expect(
        result,
        orderedEquals(
          [
            'a,c,e,g',
            'a,c,e,h',
            'a,c,f,g',
            'a,c,f,h',
            'a,d,e,g',
            'a,d,e,h',
            'a,d,f,g',
            'a,d,f,h',
            'b,c,e,g',
            'b,c,e,h',
            'b,c,f,g',
            'b,c,f,h',
            'b,d,e,g',
            'b,d,e,h',
            'b,d,f,g',
            'b,d,f,h',
          ],
        ),
      );
    });

    test('five lists', () {
      final list = ['a', 'b'];
      final l2 = ['c', 'd'];
      final l3 = ['e', 'f'];
      final l4 = ['g', 'h'];
      final l5 = ['i', 'j'];
      final result = list.cartesianSelect5(
        l2,
        l3,
        l4,
        l5,
        (a, b, c, d, e) => '$a,$b,$c,$d,$e',
      );
      expect(
        result,
        orderedEquals(
          [
            'a,c,e,g,i',
            'a,c,e,g,j',
            'a,c,e,h,i',
            'a,c,e,h,j',
            'a,c,f,g,i',
            'a,c,f,g,j',
            'a,c,f,h,i',
            'a,c,f,h,j',
            'a,d,e,g,i',
            'a,d,e,g,j',
            'a,d,e,h,i',
            'a,d,e,h,j',
            'a,d,f,g,i',
            'a,d,f,g,j',
            'a,d,f,h,i',
            'a,d,f,h,j',
            'b,c,e,g,i',
            'b,c,e,g,j',
            'b,c,e,h,i',
            'b,c,e,h,j',
            'b,c,f,g,i',
            'b,c,f,g,j',
            'b,c,f,h,i',
            'b,c,f,h,j',
            'b,d,e,g,i',
            'b,d,e,g,j',
            'b,d,e,h,i',
            'b,d,e,h,j',
            'b,d,f,g,i',
            'b,d,f,g,j',
            'b,d,f,h,i',
            'b,d,f,h,j',
          ],
        ),
      );
    });

    test('six lists', () {
      final list = ['a', 'b'];
      final l2 = ['c', 'd'];
      final l3 = ['e', 'f'];
      final l4 = ['g', 'h'];
      final l5 = ['i', 'j'];
      final l6 = ['k', 'l'];
      final result = list.cartesianSelect6(
        l2,
        l3,
        l4,
        l5,
        l6,
        (a, b, c, d, e, f) => '$a,$b,$c,$d,$e,$f',
      );
      expect(
        result,
        orderedEquals(
          [
            'a,c,e,g,i,k',
            'a,c,e,g,i,l',
            'a,c,e,g,j,k',
            'a,c,e,g,j,l',
            'a,c,e,h,i,k',
            'a,c,e,h,i,l',
            'a,c,e,h,j,k',
            'a,c,e,h,j,l',
            'a,c,f,g,i,k',
            'a,c,f,g,i,l',
            'a,c,f,g,j,k',
            'a,c,f,g,j,l',
            'a,c,f,h,i,k',
            'a,c,f,h,i,l',
            'a,c,f,h,j,k',
            'a,c,f,h,j,l',
            'a,d,e,g,i,k',
            'a,d,e,g,i,l',
            'a,d,e,g,j,k',
            'a,d,e,g,j,l',
            'a,d,e,h,i,k',
            'a,d,e,h,i,l',
            'a,d,e,h,j,k',
            'a,d,e,h,j,l',
            'a,d,f,g,i,k',
            'a,d,f,g,i,l',
            'a,d,f,g,j,k',
            'a,d,f,g,j,l',
            'a,d,f,h,i,k',
            'a,d,f,h,i,l',
            'a,d,f,h,j,k',
            'a,d,f,h,j,l',
            'b,c,e,g,i,k',
            'b,c,e,g,i,l',
            'b,c,e,g,j,k',
            'b,c,e,g,j,l',
            'b,c,e,h,i,k',
            'b,c,e,h,i,l',
            'b,c,e,h,j,k',
            'b,c,e,h,j,l',
            'b,c,f,g,i,k',
            'b,c,f,g,i,l',
            'b,c,f,g,j,k',
            'b,c,f,g,j,l',
            'b,c,f,h,i,k',
            'b,c,f,h,i,l',
            'b,c,f,h,j,k',
            'b,c,f,h,j,l',
            'b,d,e,g,i,k',
            'b,d,e,g,i,l',
            'b,d,e,g,j,k',
            'b,d,e,g,j,l',
            'b,d,e,h,i,k',
            'b,d,e,h,i,l',
            'b,d,e,h,j,k',
            'b,d,e,h,j,l',
            'b,d,f,g,i,k',
            'b,d,f,g,i,l',
            'b,d,f,g,j,k',
            'b,d,f,g,j,l',
            'b,d,f,h,i,k',
            'b,d,f,h,i,l',
            'b,d,f,h,j,k',
            'b,d,f,h,j,l',
          ],
        ),
      );
    });

    test('seven lists', () {
      final list = ['a', 'b'];
      final l2 = ['c', 'd'];
      final l3 = ['e', 'f'];
      final l4 = ['g', 'h'];
      final l5 = ['i', 'j'];
      final l6 = ['k', 'l'];
      final l7 = ['m', 'n'];
      final result = list.cartesianSelect7(
        l2,
        l3,
        l4,
        l5,
        l6,
        l7,
        (a, b, c, d, e, f, g) => '$a,$b,$c,$d,$e,$f,$g',
      );
      expect(
        result,
        orderedEquals(
          [
            'a,c,e,g,i,k,m',
            'a,c,e,g,i,k,n',
            'a,c,e,g,i,l,m',
            'a,c,e,g,i,l,n',
            'a,c,e,g,j,k,m',
            'a,c,e,g,j,k,n',
            'a,c,e,g,j,l,m',
            'a,c,e,g,j,l,n',
            'a,c,e,h,i,k,m',
            'a,c,e,h,i,k,n',
            'a,c,e,h,i,l,m',
            'a,c,e,h,i,l,n',
            'a,c,e,h,j,k,m',
            'a,c,e,h,j,k,n',
            'a,c,e,h,j,l,m',
            'a,c,e,h,j,l,n',
            'a,c,f,g,i,k,m',
            'a,c,f,g,i,k,n',
            'a,c,f,g,i,l,m',
            'a,c,f,g,i,l,n',
            'a,c,f,g,j,k,m',
            'a,c,f,g,j,k,n',
            'a,c,f,g,j,l,m',
            'a,c,f,g,j,l,n',
            'a,c,f,h,i,k,m',
            'a,c,f,h,i,k,n',
            'a,c,f,h,i,l,m',
            'a,c,f,h,i,l,n',
            'a,c,f,h,j,k,m',
            'a,c,f,h,j,k,n',
            'a,c,f,h,j,l,m',
            'a,c,f,h,j,l,n',
            'a,d,e,g,i,k,m',
            'a,d,e,g,i,k,n',
            'a,d,e,g,i,l,m',
            'a,d,e,g,i,l,n',
            'a,d,e,g,j,k,m',
            'a,d,e,g,j,k,n',
            'a,d,e,g,j,l,m',
            'a,d,e,g,j,l,n',
            'a,d,e,h,i,k,m',
            'a,d,e,h,i,k,n',
            'a,d,e,h,i,l,m',
            'a,d,e,h,i,l,n',
            'a,d,e,h,j,k,m',
            'a,d,e,h,j,k,n',
            'a,d,e,h,j,l,m',
            'a,d,e,h,j,l,n',
            'a,d,f,g,i,k,m',
            'a,d,f,g,i,k,n',
            'a,d,f,g,i,l,m',
            'a,d,f,g,i,l,n',
            'a,d,f,g,j,k,m',
            'a,d,f,g,j,k,n',
            'a,d,f,g,j,l,m',
            'a,d,f,g,j,l,n',
            'a,d,f,h,i,k,m',
            'a,d,f,h,i,k,n',
            'a,d,f,h,i,l,m',
            'a,d,f,h,i,l,n',
            'a,d,f,h,j,k,m',
            'a,d,f,h,j,k,n',
            'a,d,f,h,j,l,m',
            'a,d,f,h,j,l,n',
            'b,c,e,g,i,k,m',
            'b,c,e,g,i,k,n',
            'b,c,e,g,i,l,m',
            'b,c,e,g,i,l,n',
            'b,c,e,g,j,k,m',
            'b,c,e,g,j,k,n',
            'b,c,e,g,j,l,m',
            'b,c,e,g,j,l,n',
            'b,c,e,h,i,k,m',
            'b,c,e,h,i,k,n',
            'b,c,e,h,i,l,m',
            'b,c,e,h,i,l,n',
            'b,c,e,h,j,k,m',
            'b,c,e,h,j,k,n',
            'b,c,e,h,j,l,m',
            'b,c,e,h,j,l,n',
            'b,c,f,g,i,k,m',
            'b,c,f,g,i,k,n',
            'b,c,f,g,i,l,m',
            'b,c,f,g,i,l,n',
            'b,c,f,g,j,k,m',
            'b,c,f,g,j,k,n',
            'b,c,f,g,j,l,m',
            'b,c,f,g,j,l,n',
            'b,c,f,h,i,k,m',
            'b,c,f,h,i,k,n',
            'b,c,f,h,i,l,m',
            'b,c,f,h,i,l,n',
            'b,c,f,h,j,k,m',
            'b,c,f,h,j,k,n',
            'b,c,f,h,j,l,m',
            'b,c,f,h,j,l,n',
            'b,d,e,g,i,k,m',
            'b,d,e,g,i,k,n',
            'b,d,e,g,i,l,m',
            'b,d,e,g,i,l,n',
            'b,d,e,g,j,k,m',
            'b,d,e,g,j,k,n',
            'b,d,e,g,j,l,m',
            'b,d,e,g,j,l,n',
            'b,d,e,h,i,k,m',
            'b,d,e,h,i,k,n',
            'b,d,e,h,i,l,m',
            'b,d,e,h,i,l,n',
            'b,d,e,h,j,k,m',
            'b,d,e,h,j,k,n',
            'b,d,e,h,j,l,m',
            'b,d,e,h,j,l,n',
            'b,d,f,g,i,k,m',
            'b,d,f,g,i,k,n',
            'b,d,f,g,i,l,m',
            'b,d,f,g,i,l,n',
            'b,d,f,g,j,k,m',
            'b,d,f,g,j,k,n',
            'b,d,f,g,j,l,m',
            'b,d,f,g,j,l,n',
            'b,d,f,h,i,k,m',
            'b,d,f,h,i,k,n',
            'b,d,f,h,i,l,m',
            'b,d,f,h,i,l,n',
            'b,d,f,h,j,k,m',
            'b,d,f,h,j,k,n',
            'b,d,f,h,j,l,m',
            'b,d,f,h,j,l,n',
          ],
        ),
      );
    });

    test('eight lists', () {
      final list = ['a', 'b'];
      final l2 = ['c', 'd'];
      final l3 = ['e', 'f'];
      final l4 = ['g', 'h'];
      final l5 = ['i', 'j'];
      final l6 = ['k', 'l'];
      final l7 = ['m', 'n'];
      final l8 = ['o', 'p'];
      final result = list.cartesianSelect8(
        l2,
        l3,
        l4,
        l5,
        l6,
        l7,
        l8,
        (a, b, c, d, e, f, g, h) => '$a,$b,$c,$d,$e,$f,$g,$h',
      );
      expect(
        result,
        orderedEquals(
          [
            'a,c,e,g,i,k,m,o',
            'a,c,e,g,i,k,m,p',
            'a,c,e,g,i,k,n,o',
            'a,c,e,g,i,k,n,p',
            'a,c,e,g,i,l,m,o',
            'a,c,e,g,i,l,m,p',
            'a,c,e,g,i,l,n,o',
            'a,c,e,g,i,l,n,p',
            'a,c,e,g,j,k,m,o',
            'a,c,e,g,j,k,m,p',
            'a,c,e,g,j,k,n,o',
            'a,c,e,g,j,k,n,p',
            'a,c,e,g,j,l,m,o',
            'a,c,e,g,j,l,m,p',
            'a,c,e,g,j,l,n,o',
            'a,c,e,g,j,l,n,p',
            'a,c,e,h,i,k,m,o',
            'a,c,e,h,i,k,m,p',
            'a,c,e,h,i,k,n,o',
            'a,c,e,h,i,k,n,p',
            'a,c,e,h,i,l,m,o',
            'a,c,e,h,i,l,m,p',
            'a,c,e,h,i,l,n,o',
            'a,c,e,h,i,l,n,p',
            'a,c,e,h,j,k,m,o',
            'a,c,e,h,j,k,m,p',
            'a,c,e,h,j,k,n,o',
            'a,c,e,h,j,k,n,p',
            'a,c,e,h,j,l,m,o',
            'a,c,e,h,j,l,m,p',
            'a,c,e,h,j,l,n,o',
            'a,c,e,h,j,l,n,p',
            'a,c,f,g,i,k,m,o',
            'a,c,f,g,i,k,m,p',
            'a,c,f,g,i,k,n,o',
            'a,c,f,g,i,k,n,p',
            'a,c,f,g,i,l,m,o',
            'a,c,f,g,i,l,m,p',
            'a,c,f,g,i,l,n,o',
            'a,c,f,g,i,l,n,p',
            'a,c,f,g,j,k,m,o',
            'a,c,f,g,j,k,m,p',
            'a,c,f,g,j,k,n,o',
            'a,c,f,g,j,k,n,p',
            'a,c,f,g,j,l,m,o',
            'a,c,f,g,j,l,m,p',
            'a,c,f,g,j,l,n,o',
            'a,c,f,g,j,l,n,p',
            'a,c,f,h,i,k,m,o',
            'a,c,f,h,i,k,m,p',
            'a,c,f,h,i,k,n,o',
            'a,c,f,h,i,k,n,p',
            'a,c,f,h,i,l,m,o',
            'a,c,f,h,i,l,m,p',
            'a,c,f,h,i,l,n,o',
            'a,c,f,h,i,l,n,p',
            'a,c,f,h,j,k,m,o',
            'a,c,f,h,j,k,m,p',
            'a,c,f,h,j,k,n,o',
            'a,c,f,h,j,k,n,p',
            'a,c,f,h,j,l,m,o',
            'a,c,f,h,j,l,m,p',
            'a,c,f,h,j,l,n,o',
            'a,c,f,h,j,l,n,p',
            'a,d,e,g,i,k,m,o',
            'a,d,e,g,i,k,m,p',
            'a,d,e,g,i,k,n,o',
            'a,d,e,g,i,k,n,p',
            'a,d,e,g,i,l,m,o',
            'a,d,e,g,i,l,m,p',
            'a,d,e,g,i,l,n,o',
            'a,d,e,g,i,l,n,p',
            'a,d,e,g,j,k,m,o',
            'a,d,e,g,j,k,m,p',
            'a,d,e,g,j,k,n,o',
            'a,d,e,g,j,k,n,p',
            'a,d,e,g,j,l,m,o',
            'a,d,e,g,j,l,m,p',
            'a,d,e,g,j,l,n,o',
            'a,d,e,g,j,l,n,p',
            'a,d,e,h,i,k,m,o',
            'a,d,e,h,i,k,m,p',
            'a,d,e,h,i,k,n,o',
            'a,d,e,h,i,k,n,p',
            'a,d,e,h,i,l,m,o',
            'a,d,e,h,i,l,m,p',
            'a,d,e,h,i,l,n,o',
            'a,d,e,h,i,l,n,p',
            'a,d,e,h,j,k,m,o',
            'a,d,e,h,j,k,m,p',
            'a,d,e,h,j,k,n,o',
            'a,d,e,h,j,k,n,p',
            'a,d,e,h,j,l,m,o',
            'a,d,e,h,j,l,m,p',
            'a,d,e,h,j,l,n,o',
            'a,d,e,h,j,l,n,p',
            'a,d,f,g,i,k,m,o',
            'a,d,f,g,i,k,m,p',
            'a,d,f,g,i,k,n,o',
            'a,d,f,g,i,k,n,p',
            'a,d,f,g,i,l,m,o',
            'a,d,f,g,i,l,m,p',
            'a,d,f,g,i,l,n,o',
            'a,d,f,g,i,l,n,p',
            'a,d,f,g,j,k,m,o',
            'a,d,f,g,j,k,m,p',
            'a,d,f,g,j,k,n,o',
            'a,d,f,g,j,k,n,p',
            'a,d,f,g,j,l,m,o',
            'a,d,f,g,j,l,m,p',
            'a,d,f,g,j,l,n,o',
            'a,d,f,g,j,l,n,p',
            'a,d,f,h,i,k,m,o',
            'a,d,f,h,i,k,m,p',
            'a,d,f,h,i,k,n,o',
            'a,d,f,h,i,k,n,p',
            'a,d,f,h,i,l,m,o',
            'a,d,f,h,i,l,m,p',
            'a,d,f,h,i,l,n,o',
            'a,d,f,h,i,l,n,p',
            'a,d,f,h,j,k,m,o',
            'a,d,f,h,j,k,m,p',
            'a,d,f,h,j,k,n,o',
            'a,d,f,h,j,k,n,p',
            'a,d,f,h,j,l,m,o',
            'a,d,f,h,j,l,m,p',
            'a,d,f,h,j,l,n,o',
            'a,d,f,h,j,l,n,p',
            'b,c,e,g,i,k,m,o',
            'b,c,e,g,i,k,m,p',
            'b,c,e,g,i,k,n,o',
            'b,c,e,g,i,k,n,p',
            'b,c,e,g,i,l,m,o',
            'b,c,e,g,i,l,m,p',
            'b,c,e,g,i,l,n,o',
            'b,c,e,g,i,l,n,p',
            'b,c,e,g,j,k,m,o',
            'b,c,e,g,j,k,m,p',
            'b,c,e,g,j,k,n,o',
            'b,c,e,g,j,k,n,p',
            'b,c,e,g,j,l,m,o',
            'b,c,e,g,j,l,m,p',
            'b,c,e,g,j,l,n,o',
            'b,c,e,g,j,l,n,p',
            'b,c,e,h,i,k,m,o',
            'b,c,e,h,i,k,m,p',
            'b,c,e,h,i,k,n,o',
            'b,c,e,h,i,k,n,p',
            'b,c,e,h,i,l,m,o',
            'b,c,e,h,i,l,m,p',
            'b,c,e,h,i,l,n,o',
            'b,c,e,h,i,l,n,p',
            'b,c,e,h,j,k,m,o',
            'b,c,e,h,j,k,m,p',
            'b,c,e,h,j,k,n,o',
            'b,c,e,h,j,k,n,p',
            'b,c,e,h,j,l,m,o',
            'b,c,e,h,j,l,m,p',
            'b,c,e,h,j,l,n,o',
            'b,c,e,h,j,l,n,p',
            'b,c,f,g,i,k,m,o',
            'b,c,f,g,i,k,m,p',
            'b,c,f,g,i,k,n,o',
            'b,c,f,g,i,k,n,p',
            'b,c,f,g,i,l,m,o',
            'b,c,f,g,i,l,m,p',
            'b,c,f,g,i,l,n,o',
            'b,c,f,g,i,l,n,p',
            'b,c,f,g,j,k,m,o',
            'b,c,f,g,j,k,m,p',
            'b,c,f,g,j,k,n,o',
            'b,c,f,g,j,k,n,p',
            'b,c,f,g,j,l,m,o',
            'b,c,f,g,j,l,m,p',
            'b,c,f,g,j,l,n,o',
            'b,c,f,g,j,l,n,p',
            'b,c,f,h,i,k,m,o',
            'b,c,f,h,i,k,m,p',
            'b,c,f,h,i,k,n,o',
            'b,c,f,h,i,k,n,p',
            'b,c,f,h,i,l,m,o',
            'b,c,f,h,i,l,m,p',
            'b,c,f,h,i,l,n,o',
            'b,c,f,h,i,l,n,p',
            'b,c,f,h,j,k,m,o',
            'b,c,f,h,j,k,m,p',
            'b,c,f,h,j,k,n,o',
            'b,c,f,h,j,k,n,p',
            'b,c,f,h,j,l,m,o',
            'b,c,f,h,j,l,m,p',
            'b,c,f,h,j,l,n,o',
            'b,c,f,h,j,l,n,p',
            'b,d,e,g,i,k,m,o',
            'b,d,e,g,i,k,m,p',
            'b,d,e,g,i,k,n,o',
            'b,d,e,g,i,k,n,p',
            'b,d,e,g,i,l,m,o',
            'b,d,e,g,i,l,m,p',
            'b,d,e,g,i,l,n,o',
            'b,d,e,g,i,l,n,p',
            'b,d,e,g,j,k,m,o',
            'b,d,e,g,j,k,m,p',
            'b,d,e,g,j,k,n,o',
            'b,d,e,g,j,k,n,p',
            'b,d,e,g,j,l,m,o',
            'b,d,e,g,j,l,m,p',
            'b,d,e,g,j,l,n,o',
            'b,d,e,g,j,l,n,p',
            'b,d,e,h,i,k,m,o',
            'b,d,e,h,i,k,m,p',
            'b,d,e,h,i,k,n,o',
            'b,d,e,h,i,k,n,p',
            'b,d,e,h,i,l,m,o',
            'b,d,e,h,i,l,m,p',
            'b,d,e,h,i,l,n,o',
            'b,d,e,h,i,l,n,p',
            'b,d,e,h,j,k,m,o',
            'b,d,e,h,j,k,m,p',
            'b,d,e,h,j,k,n,o',
            'b,d,e,h,j,k,n,p',
            'b,d,e,h,j,l,m,o',
            'b,d,e,h,j,l,m,p',
            'b,d,e,h,j,l,n,o',
            'b,d,e,h,j,l,n,p',
            'b,d,f,g,i,k,m,o',
            'b,d,f,g,i,k,m,p',
            'b,d,f,g,i,k,n,o',
            'b,d,f,g,i,k,n,p',
            'b,d,f,g,i,l,m,o',
            'b,d,f,g,i,l,m,p',
            'b,d,f,g,i,l,n,o',
            'b,d,f,g,i,l,n,p',
            'b,d,f,g,j,k,m,o',
            'b,d,f,g,j,k,m,p',
            'b,d,f,g,j,k,n,o',
            'b,d,f,g,j,k,n,p',
            'b,d,f,g,j,l,m,o',
            'b,d,f,g,j,l,m,p',
            'b,d,f,g,j,l,n,o',
            'b,d,f,g,j,l,n,p',
            'b,d,f,h,i,k,m,o',
            'b,d,f,h,i,k,m,p',
            'b,d,f,h,i,k,n,o',
            'b,d,f,h,i,k,n,p',
            'b,d,f,h,i,l,m,o',
            'b,d,f,h,i,l,m,p',
            'b,d,f,h,i,l,n,o',
            'b,d,f,h,i,l,n,p',
            'b,d,f,h,j,k,m,o',
            'b,d,f,h,j,k,m,p',
            'b,d,f,h,j,k,n,o',
            'b,d,f,h,j,k,n,p',
            'b,d,f,h,j,l,m,o',
            'b,d,f,h,j,l,m,p',
            'b,d,f,h,j,l,n,o',
            'b,d,f,h,j,l,n,p',
          ],
        ),
      );
    });

    test('nine lists', () {
      final list = ['a', 'b'];
      final l2 = ['c', 'd'];
      final l3 = ['e', 'f'];
      final l4 = ['g', 'h'];
      final l5 = ['i', 'j'];
      final l6 = ['k', 'l'];
      final l7 = ['m', 'n'];
      final l8 = ['o', 'p'];
      final l9 = ['q', 'r'];
      final result = list.cartesianSelect9(
        l2,
        l3,
        l4,
        l5,
        l6,
        l7,
        l8,
        l9,
        (a, b, c, d, e, f, g, h, i) => '$a,$b,$c,$d,$e,$f,$g,$h,$i',
      );
      expect(
        result,
        orderedEquals(
          [
            'a,c,e,g,i,k,m,o,q',
            'a,c,e,g,i,k,m,o,r',
            'a,c,e,g,i,k,m,p,q',
            'a,c,e,g,i,k,m,p,r',
            'a,c,e,g,i,k,n,o,q',
            'a,c,e,g,i,k,n,o,r',
            'a,c,e,g,i,k,n,p,q',
            'a,c,e,g,i,k,n,p,r',
            'a,c,e,g,i,l,m,o,q',
            'a,c,e,g,i,l,m,o,r',
            'a,c,e,g,i,l,m,p,q',
            'a,c,e,g,i,l,m,p,r',
            'a,c,e,g,i,l,n,o,q',
            'a,c,e,g,i,l,n,o,r',
            'a,c,e,g,i,l,n,p,q',
            'a,c,e,g,i,l,n,p,r',
            'a,c,e,g,j,k,m,o,q',
            'a,c,e,g,j,k,m,o,r',
            'a,c,e,g,j,k,m,p,q',
            'a,c,e,g,j,k,m,p,r',
            'a,c,e,g,j,k,n,o,q',
            'a,c,e,g,j,k,n,o,r',
            'a,c,e,g,j,k,n,p,q',
            'a,c,e,g,j,k,n,p,r',
            'a,c,e,g,j,l,m,o,q',
            'a,c,e,g,j,l,m,o,r',
            'a,c,e,g,j,l,m,p,q',
            'a,c,e,g,j,l,m,p,r',
            'a,c,e,g,j,l,n,o,q',
            'a,c,e,g,j,l,n,o,r',
            'a,c,e,g,j,l,n,p,q',
            'a,c,e,g,j,l,n,p,r',
            'a,c,e,h,i,k,m,o,q',
            'a,c,e,h,i,k,m,o,r',
            'a,c,e,h,i,k,m,p,q',
            'a,c,e,h,i,k,m,p,r',
            'a,c,e,h,i,k,n,o,q',
            'a,c,e,h,i,k,n,o,r',
            'a,c,e,h,i,k,n,p,q',
            'a,c,e,h,i,k,n,p,r',
            'a,c,e,h,i,l,m,o,q',
            'a,c,e,h,i,l,m,o,r',
            'a,c,e,h,i,l,m,p,q',
            'a,c,e,h,i,l,m,p,r',
            'a,c,e,h,i,l,n,o,q',
            'a,c,e,h,i,l,n,o,r',
            'a,c,e,h,i,l,n,p,q',
            'a,c,e,h,i,l,n,p,r',
            'a,c,e,h,j,k,m,o,q',
            'a,c,e,h,j,k,m,o,r',
            'a,c,e,h,j,k,m,p,q',
            'a,c,e,h,j,k,m,p,r',
            'a,c,e,h,j,k,n,o,q',
            'a,c,e,h,j,k,n,o,r',
            'a,c,e,h,j,k,n,p,q',
            'a,c,e,h,j,k,n,p,r',
            'a,c,e,h,j,l,m,o,q',
            'a,c,e,h,j,l,m,o,r',
            'a,c,e,h,j,l,m,p,q',
            'a,c,e,h,j,l,m,p,r',
            'a,c,e,h,j,l,n,o,q',
            'a,c,e,h,j,l,n,o,r',
            'a,c,e,h,j,l,n,p,q',
            'a,c,e,h,j,l,n,p,r',
            'a,c,f,g,i,k,m,o,q',
            'a,c,f,g,i,k,m,o,r',
            'a,c,f,g,i,k,m,p,q',
            'a,c,f,g,i,k,m,p,r',
            'a,c,f,g,i,k,n,o,q',
            'a,c,f,g,i,k,n,o,r',
            'a,c,f,g,i,k,n,p,q',
            'a,c,f,g,i,k,n,p,r',
            'a,c,f,g,i,l,m,o,q',
            'a,c,f,g,i,l,m,o,r',
            'a,c,f,g,i,l,m,p,q',
            'a,c,f,g,i,l,m,p,r',
            'a,c,f,g,i,l,n,o,q',
            'a,c,f,g,i,l,n,o,r',
            'a,c,f,g,i,l,n,p,q',
            'a,c,f,g,i,l,n,p,r',
            'a,c,f,g,j,k,m,o,q',
            'a,c,f,g,j,k,m,o,r',
            'a,c,f,g,j,k,m,p,q',
            'a,c,f,g,j,k,m,p,r',
            'a,c,f,g,j,k,n,o,q',
            'a,c,f,g,j,k,n,o,r',
            'a,c,f,g,j,k,n,p,q',
            'a,c,f,g,j,k,n,p,r',
            'a,c,f,g,j,l,m,o,q',
            'a,c,f,g,j,l,m,o,r',
            'a,c,f,g,j,l,m,p,q',
            'a,c,f,g,j,l,m,p,r',
            'a,c,f,g,j,l,n,o,q',
            'a,c,f,g,j,l,n,o,r',
            'a,c,f,g,j,l,n,p,q',
            'a,c,f,g,j,l,n,p,r',
            'a,c,f,h,i,k,m,o,q',
            'a,c,f,h,i,k,m,o,r',
            'a,c,f,h,i,k,m,p,q',
            'a,c,f,h,i,k,m,p,r',
            'a,c,f,h,i,k,n,o,q',
            'a,c,f,h,i,k,n,o,r',
            'a,c,f,h,i,k,n,p,q',
            'a,c,f,h,i,k,n,p,r',
            'a,c,f,h,i,l,m,o,q',
            'a,c,f,h,i,l,m,o,r',
            'a,c,f,h,i,l,m,p,q',
            'a,c,f,h,i,l,m,p,r',
            'a,c,f,h,i,l,n,o,q',
            'a,c,f,h,i,l,n,o,r',
            'a,c,f,h,i,l,n,p,q',
            'a,c,f,h,i,l,n,p,r',
            'a,c,f,h,j,k,m,o,q',
            'a,c,f,h,j,k,m,o,r',
            'a,c,f,h,j,k,m,p,q',
            'a,c,f,h,j,k,m,p,r',
            'a,c,f,h,j,k,n,o,q',
            'a,c,f,h,j,k,n,o,r',
            'a,c,f,h,j,k,n,p,q',
            'a,c,f,h,j,k,n,p,r',
            'a,c,f,h,j,l,m,o,q',
            'a,c,f,h,j,l,m,o,r',
            'a,c,f,h,j,l,m,p,q',
            'a,c,f,h,j,l,m,p,r',
            'a,c,f,h,j,l,n,o,q',
            'a,c,f,h,j,l,n,o,r',
            'a,c,f,h,j,l,n,p,q',
            'a,c,f,h,j,l,n,p,r',
            'a,d,e,g,i,k,m,o,q',
            'a,d,e,g,i,k,m,o,r',
            'a,d,e,g,i,k,m,p,q',
            'a,d,e,g,i,k,m,p,r',
            'a,d,e,g,i,k,n,o,q',
            'a,d,e,g,i,k,n,o,r',
            'a,d,e,g,i,k,n,p,q',
            'a,d,e,g,i,k,n,p,r',
            'a,d,e,g,i,l,m,o,q',
            'a,d,e,g,i,l,m,o,r',
            'a,d,e,g,i,l,m,p,q',
            'a,d,e,g,i,l,m,p,r',
            'a,d,e,g,i,l,n,o,q',
            'a,d,e,g,i,l,n,o,r',
            'a,d,e,g,i,l,n,p,q',
            'a,d,e,g,i,l,n,p,r',
            'a,d,e,g,j,k,m,o,q',
            'a,d,e,g,j,k,m,o,r',
            'a,d,e,g,j,k,m,p,q',
            'a,d,e,g,j,k,m,p,r',
            'a,d,e,g,j,k,n,o,q',
            'a,d,e,g,j,k,n,o,r',
            'a,d,e,g,j,k,n,p,q',
            'a,d,e,g,j,k,n,p,r',
            'a,d,e,g,j,l,m,o,q',
            'a,d,e,g,j,l,m,o,r',
            'a,d,e,g,j,l,m,p,q',
            'a,d,e,g,j,l,m,p,r',
            'a,d,e,g,j,l,n,o,q',
            'a,d,e,g,j,l,n,o,r',
            'a,d,e,g,j,l,n,p,q',
            'a,d,e,g,j,l,n,p,r',
            'a,d,e,h,i,k,m,o,q',
            'a,d,e,h,i,k,m,o,r',
            'a,d,e,h,i,k,m,p,q',
            'a,d,e,h,i,k,m,p,r',
            'a,d,e,h,i,k,n,o,q',
            'a,d,e,h,i,k,n,o,r',
            'a,d,e,h,i,k,n,p,q',
            'a,d,e,h,i,k,n,p,r',
            'a,d,e,h,i,l,m,o,q',
            'a,d,e,h,i,l,m,o,r',
            'a,d,e,h,i,l,m,p,q',
            'a,d,e,h,i,l,m,p,r',
            'a,d,e,h,i,l,n,o,q',
            'a,d,e,h,i,l,n,o,r',
            'a,d,e,h,i,l,n,p,q',
            'a,d,e,h,i,l,n,p,r',
            'a,d,e,h,j,k,m,o,q',
            'a,d,e,h,j,k,m,o,r',
            'a,d,e,h,j,k,m,p,q',
            'a,d,e,h,j,k,m,p,r',
            'a,d,e,h,j,k,n,o,q',
            'a,d,e,h,j,k,n,o,r',
            'a,d,e,h,j,k,n,p,q',
            'a,d,e,h,j,k,n,p,r',
            'a,d,e,h,j,l,m,o,q',
            'a,d,e,h,j,l,m,o,r',
            'a,d,e,h,j,l,m,p,q',
            'a,d,e,h,j,l,m,p,r',
            'a,d,e,h,j,l,n,o,q',
            'a,d,e,h,j,l,n,o,r',
            'a,d,e,h,j,l,n,p,q',
            'a,d,e,h,j,l,n,p,r',
            'a,d,f,g,i,k,m,o,q',
            'a,d,f,g,i,k,m,o,r',
            'a,d,f,g,i,k,m,p,q',
            'a,d,f,g,i,k,m,p,r',
            'a,d,f,g,i,k,n,o,q',
            'a,d,f,g,i,k,n,o,r',
            'a,d,f,g,i,k,n,p,q',
            'a,d,f,g,i,k,n,p,r',
            'a,d,f,g,i,l,m,o,q',
            'a,d,f,g,i,l,m,o,r',
            'a,d,f,g,i,l,m,p,q',
            'a,d,f,g,i,l,m,p,r',
            'a,d,f,g,i,l,n,o,q',
            'a,d,f,g,i,l,n,o,r',
            'a,d,f,g,i,l,n,p,q',
            'a,d,f,g,i,l,n,p,r',
            'a,d,f,g,j,k,m,o,q',
            'a,d,f,g,j,k,m,o,r',
            'a,d,f,g,j,k,m,p,q',
            'a,d,f,g,j,k,m,p,r',
            'a,d,f,g,j,k,n,o,q',
            'a,d,f,g,j,k,n,o,r',
            'a,d,f,g,j,k,n,p,q',
            'a,d,f,g,j,k,n,p,r',
            'a,d,f,g,j,l,m,o,q',
            'a,d,f,g,j,l,m,o,r',
            'a,d,f,g,j,l,m,p,q',
            'a,d,f,g,j,l,m,p,r',
            'a,d,f,g,j,l,n,o,q',
            'a,d,f,g,j,l,n,o,r',
            'a,d,f,g,j,l,n,p,q',
            'a,d,f,g,j,l,n,p,r',
            'a,d,f,h,i,k,m,o,q',
            'a,d,f,h,i,k,m,o,r',
            'a,d,f,h,i,k,m,p,q',
            'a,d,f,h,i,k,m,p,r',
            'a,d,f,h,i,k,n,o,q',
            'a,d,f,h,i,k,n,o,r',
            'a,d,f,h,i,k,n,p,q',
            'a,d,f,h,i,k,n,p,r',
            'a,d,f,h,i,l,m,o,q',
            'a,d,f,h,i,l,m,o,r',
            'a,d,f,h,i,l,m,p,q',
            'a,d,f,h,i,l,m,p,r',
            'a,d,f,h,i,l,n,o,q',
            'a,d,f,h,i,l,n,o,r',
            'a,d,f,h,i,l,n,p,q',
            'a,d,f,h,i,l,n,p,r',
            'a,d,f,h,j,k,m,o,q',
            'a,d,f,h,j,k,m,o,r',
            'a,d,f,h,j,k,m,p,q',
            'a,d,f,h,j,k,m,p,r',
            'a,d,f,h,j,k,n,o,q',
            'a,d,f,h,j,k,n,o,r',
            'a,d,f,h,j,k,n,p,q',
            'a,d,f,h,j,k,n,p,r',
            'a,d,f,h,j,l,m,o,q',
            'a,d,f,h,j,l,m,o,r',
            'a,d,f,h,j,l,m,p,q',
            'a,d,f,h,j,l,m,p,r',
            'a,d,f,h,j,l,n,o,q',
            'a,d,f,h,j,l,n,o,r',
            'a,d,f,h,j,l,n,p,q',
            'a,d,f,h,j,l,n,p,r',
            'b,c,e,g,i,k,m,o,q',
            'b,c,e,g,i,k,m,o,r',
            'b,c,e,g,i,k,m,p,q',
            'b,c,e,g,i,k,m,p,r',
            'b,c,e,g,i,k,n,o,q',
            'b,c,e,g,i,k,n,o,r',
            'b,c,e,g,i,k,n,p,q',
            'b,c,e,g,i,k,n,p,r',
            'b,c,e,g,i,l,m,o,q',
            'b,c,e,g,i,l,m,o,r',
            'b,c,e,g,i,l,m,p,q',
            'b,c,e,g,i,l,m,p,r',
            'b,c,e,g,i,l,n,o,q',
            'b,c,e,g,i,l,n,o,r',
            'b,c,e,g,i,l,n,p,q',
            'b,c,e,g,i,l,n,p,r',
            'b,c,e,g,j,k,m,o,q',
            'b,c,e,g,j,k,m,o,r',
            'b,c,e,g,j,k,m,p,q',
            'b,c,e,g,j,k,m,p,r',
            'b,c,e,g,j,k,n,o,q',
            'b,c,e,g,j,k,n,o,r',
            'b,c,e,g,j,k,n,p,q',
            'b,c,e,g,j,k,n,p,r',
            'b,c,e,g,j,l,m,o,q',
            'b,c,e,g,j,l,m,o,r',
            'b,c,e,g,j,l,m,p,q',
            'b,c,e,g,j,l,m,p,r',
            'b,c,e,g,j,l,n,o,q',
            'b,c,e,g,j,l,n,o,r',
            'b,c,e,g,j,l,n,p,q',
            'b,c,e,g,j,l,n,p,r',
            'b,c,e,h,i,k,m,o,q',
            'b,c,e,h,i,k,m,o,r',
            'b,c,e,h,i,k,m,p,q',
            'b,c,e,h,i,k,m,p,r',
            'b,c,e,h,i,k,n,o,q',
            'b,c,e,h,i,k,n,o,r',
            'b,c,e,h,i,k,n,p,q',
            'b,c,e,h,i,k,n,p,r',
            'b,c,e,h,i,l,m,o,q',
            'b,c,e,h,i,l,m,o,r',
            'b,c,e,h,i,l,m,p,q',
            'b,c,e,h,i,l,m,p,r',
            'b,c,e,h,i,l,n,o,q',
            'b,c,e,h,i,l,n,o,r',
            'b,c,e,h,i,l,n,p,q',
            'b,c,e,h,i,l,n,p,r',
            'b,c,e,h,j,k,m,o,q',
            'b,c,e,h,j,k,m,o,r',
            'b,c,e,h,j,k,m,p,q',
            'b,c,e,h,j,k,m,p,r',
            'b,c,e,h,j,k,n,o,q',
            'b,c,e,h,j,k,n,o,r',
            'b,c,e,h,j,k,n,p,q',
            'b,c,e,h,j,k,n,p,r',
            'b,c,e,h,j,l,m,o,q',
            'b,c,e,h,j,l,m,o,r',
            'b,c,e,h,j,l,m,p,q',
            'b,c,e,h,j,l,m,p,r',
            'b,c,e,h,j,l,n,o,q',
            'b,c,e,h,j,l,n,o,r',
            'b,c,e,h,j,l,n,p,q',
            'b,c,e,h,j,l,n,p,r',
            'b,c,f,g,i,k,m,o,q',
            'b,c,f,g,i,k,m,o,r',
            'b,c,f,g,i,k,m,p,q',
            'b,c,f,g,i,k,m,p,r',
            'b,c,f,g,i,k,n,o,q',
            'b,c,f,g,i,k,n,o,r',
            'b,c,f,g,i,k,n,p,q',
            'b,c,f,g,i,k,n,p,r',
            'b,c,f,g,i,l,m,o,q',
            'b,c,f,g,i,l,m,o,r',
            'b,c,f,g,i,l,m,p,q',
            'b,c,f,g,i,l,m,p,r',
            'b,c,f,g,i,l,n,o,q',
            'b,c,f,g,i,l,n,o,r',
            'b,c,f,g,i,l,n,p,q',
            'b,c,f,g,i,l,n,p,r',
            'b,c,f,g,j,k,m,o,q',
            'b,c,f,g,j,k,m,o,r',
            'b,c,f,g,j,k,m,p,q',
            'b,c,f,g,j,k,m,p,r',
            'b,c,f,g,j,k,n,o,q',
            'b,c,f,g,j,k,n,o,r',
            'b,c,f,g,j,k,n,p,q',
            'b,c,f,g,j,k,n,p,r',
            'b,c,f,g,j,l,m,o,q',
            'b,c,f,g,j,l,m,o,r',
            'b,c,f,g,j,l,m,p,q',
            'b,c,f,g,j,l,m,p,r',
            'b,c,f,g,j,l,n,o,q',
            'b,c,f,g,j,l,n,o,r',
            'b,c,f,g,j,l,n,p,q',
            'b,c,f,g,j,l,n,p,r',
            'b,c,f,h,i,k,m,o,q',
            'b,c,f,h,i,k,m,o,r',
            'b,c,f,h,i,k,m,p,q',
            'b,c,f,h,i,k,m,p,r',
            'b,c,f,h,i,k,n,o,q',
            'b,c,f,h,i,k,n,o,r',
            'b,c,f,h,i,k,n,p,q',
            'b,c,f,h,i,k,n,p,r',
            'b,c,f,h,i,l,m,o,q',
            'b,c,f,h,i,l,m,o,r',
            'b,c,f,h,i,l,m,p,q',
            'b,c,f,h,i,l,m,p,r',
            'b,c,f,h,i,l,n,o,q',
            'b,c,f,h,i,l,n,o,r',
            'b,c,f,h,i,l,n,p,q',
            'b,c,f,h,i,l,n,p,r',
            'b,c,f,h,j,k,m,o,q',
            'b,c,f,h,j,k,m,o,r',
            'b,c,f,h,j,k,m,p,q',
            'b,c,f,h,j,k,m,p,r',
            'b,c,f,h,j,k,n,o,q',
            'b,c,f,h,j,k,n,o,r',
            'b,c,f,h,j,k,n,p,q',
            'b,c,f,h,j,k,n,p,r',
            'b,c,f,h,j,l,m,o,q',
            'b,c,f,h,j,l,m,o,r',
            'b,c,f,h,j,l,m,p,q',
            'b,c,f,h,j,l,m,p,r',
            'b,c,f,h,j,l,n,o,q',
            'b,c,f,h,j,l,n,o,r',
            'b,c,f,h,j,l,n,p,q',
            'b,c,f,h,j,l,n,p,r',
            'b,d,e,g,i,k,m,o,q',
            'b,d,e,g,i,k,m,o,r',
            'b,d,e,g,i,k,m,p,q',
            'b,d,e,g,i,k,m,p,r',
            'b,d,e,g,i,k,n,o,q',
            'b,d,e,g,i,k,n,o,r',
            'b,d,e,g,i,k,n,p,q',
            'b,d,e,g,i,k,n,p,r',
            'b,d,e,g,i,l,m,o,q',
            'b,d,e,g,i,l,m,o,r',
            'b,d,e,g,i,l,m,p,q',
            'b,d,e,g,i,l,m,p,r',
            'b,d,e,g,i,l,n,o,q',
            'b,d,e,g,i,l,n,o,r',
            'b,d,e,g,i,l,n,p,q',
            'b,d,e,g,i,l,n,p,r',
            'b,d,e,g,j,k,m,o,q',
            'b,d,e,g,j,k,m,o,r',
            'b,d,e,g,j,k,m,p,q',
            'b,d,e,g,j,k,m,p,r',
            'b,d,e,g,j,k,n,o,q',
            'b,d,e,g,j,k,n,o,r',
            'b,d,e,g,j,k,n,p,q',
            'b,d,e,g,j,k,n,p,r',
            'b,d,e,g,j,l,m,o,q',
            'b,d,e,g,j,l,m,o,r',
            'b,d,e,g,j,l,m,p,q',
            'b,d,e,g,j,l,m,p,r',
            'b,d,e,g,j,l,n,o,q',
            'b,d,e,g,j,l,n,o,r',
            'b,d,e,g,j,l,n,p,q',
            'b,d,e,g,j,l,n,p,r',
            'b,d,e,h,i,k,m,o,q',
            'b,d,e,h,i,k,m,o,r',
            'b,d,e,h,i,k,m,p,q',
            'b,d,e,h,i,k,m,p,r',
            'b,d,e,h,i,k,n,o,q',
            'b,d,e,h,i,k,n,o,r',
            'b,d,e,h,i,k,n,p,q',
            'b,d,e,h,i,k,n,p,r',
            'b,d,e,h,i,l,m,o,q',
            'b,d,e,h,i,l,m,o,r',
            'b,d,e,h,i,l,m,p,q',
            'b,d,e,h,i,l,m,p,r',
            'b,d,e,h,i,l,n,o,q',
            'b,d,e,h,i,l,n,o,r',
            'b,d,e,h,i,l,n,p,q',
            'b,d,e,h,i,l,n,p,r',
            'b,d,e,h,j,k,m,o,q',
            'b,d,e,h,j,k,m,o,r',
            'b,d,e,h,j,k,m,p,q',
            'b,d,e,h,j,k,m,p,r',
            'b,d,e,h,j,k,n,o,q',
            'b,d,e,h,j,k,n,o,r',
            'b,d,e,h,j,k,n,p,q',
            'b,d,e,h,j,k,n,p,r',
            'b,d,e,h,j,l,m,o,q',
            'b,d,e,h,j,l,m,o,r',
            'b,d,e,h,j,l,m,p,q',
            'b,d,e,h,j,l,m,p,r',
            'b,d,e,h,j,l,n,o,q',
            'b,d,e,h,j,l,n,o,r',
            'b,d,e,h,j,l,n,p,q',
            'b,d,e,h,j,l,n,p,r',
            'b,d,f,g,i,k,m,o,q',
            'b,d,f,g,i,k,m,o,r',
            'b,d,f,g,i,k,m,p,q',
            'b,d,f,g,i,k,m,p,r',
            'b,d,f,g,i,k,n,o,q',
            'b,d,f,g,i,k,n,o,r',
            'b,d,f,g,i,k,n,p,q',
            'b,d,f,g,i,k,n,p,r',
            'b,d,f,g,i,l,m,o,q',
            'b,d,f,g,i,l,m,o,r',
            'b,d,f,g,i,l,m,p,q',
            'b,d,f,g,i,l,m,p,r',
            'b,d,f,g,i,l,n,o,q',
            'b,d,f,g,i,l,n,o,r',
            'b,d,f,g,i,l,n,p,q',
            'b,d,f,g,i,l,n,p,r',
            'b,d,f,g,j,k,m,o,q',
            'b,d,f,g,j,k,m,o,r',
            'b,d,f,g,j,k,m,p,q',
            'b,d,f,g,j,k,m,p,r',
            'b,d,f,g,j,k,n,o,q',
            'b,d,f,g,j,k,n,o,r',
            'b,d,f,g,j,k,n,p,q',
            'b,d,f,g,j,k,n,p,r',
            'b,d,f,g,j,l,m,o,q',
            'b,d,f,g,j,l,m,o,r',
            'b,d,f,g,j,l,m,p,q',
            'b,d,f,g,j,l,m,p,r',
            'b,d,f,g,j,l,n,o,q',
            'b,d,f,g,j,l,n,o,r',
            'b,d,f,g,j,l,n,p,q',
            'b,d,f,g,j,l,n,p,r',
            'b,d,f,h,i,k,m,o,q',
            'b,d,f,h,i,k,m,o,r',
            'b,d,f,h,i,k,m,p,q',
            'b,d,f,h,i,k,m,p,r',
            'b,d,f,h,i,k,n,o,q',
            'b,d,f,h,i,k,n,o,r',
            'b,d,f,h,i,k,n,p,q',
            'b,d,f,h,i,k,n,p,r',
            'b,d,f,h,i,l,m,o,q',
            'b,d,f,h,i,l,m,o,r',
            'b,d,f,h,i,l,m,p,q',
            'b,d,f,h,i,l,m,p,r',
            'b,d,f,h,i,l,n,o,q',
            'b,d,f,h,i,l,n,o,r',
            'b,d,f,h,i,l,n,p,q',
            'b,d,f,h,i,l,n,p,r',
            'b,d,f,h,j,k,m,o,q',
            'b,d,f,h,j,k,m,o,r',
            'b,d,f,h,j,k,m,p,q',
            'b,d,f,h,j,k,m,p,r',
            'b,d,f,h,j,k,n,o,q',
            'b,d,f,h,j,k,n,o,r',
            'b,d,f,h,j,k,n,p,q',
            'b,d,f,h,j,k,n,p,r',
            'b,d,f,h,j,l,m,o,q',
            'b,d,f,h,j,l,m,o,r',
            'b,d,f,h,j,l,m,p,q',
            'b,d,f,h,j,l,m,p,r',
            'b,d,f,h,j,l,n,o,q',
            'b,d,f,h,j,l,n,o,r',
            'b,d,f,h,j,l,n,p,q',
            'b,d,f,h,j,l,n,p,r',
          ],
        ),
      );
    });
  });
}
