import 'package:darq/darq.dart';
import 'package:test/test.dart';

void main() {
  group('cartesian', () {
    test('two lists', () {
      final list = ['a', 'b'];
      final other = ['c', 'd'];
      final result = list.cartesian(other);
      expect(
        result,
        orderedEquals(
          [
            Tuple2('a', 'c'),
            Tuple2('a', 'd'),
            Tuple2('b', 'c'),
            Tuple2('b', 'd'),
          ],
        ),
      );
    });

    test('three lists', () {
      final list = ['a', 'b'];
      final l2 = ['c', 'd'];
      final l3 = ['e', 'f'];
      final result = list.cartesian3(
        l2,
        l3,
      );
      expect(
        result,
        orderedEquals(
          [
            Tuple3('a', 'c', 'e'),
            Tuple3('a', 'c', 'f'),
            Tuple3('a', 'd', 'e'),
            Tuple3('a', 'd', 'f'),
            Tuple3('b', 'c', 'e'),
            Tuple3('b', 'c', 'f'),
            Tuple3('b', 'd', 'e'),
            Tuple3('b', 'd', 'f'),
          ],
        ),
      );
    });

    test('four lists', () {
      final list = ['a', 'b'];
      final l2 = ['c', 'd'];
      final l3 = ['e', 'f'];
      final l4 = ['g', 'h'];
      final result = list.cartesian4(
        l2,
        l3,
        l4,
      );
      expect(
        result,
        orderedEquals(
          [
            Tuple4('a', 'c', 'e', 'g'),
            Tuple4('a', 'c', 'e', 'h'),
            Tuple4('a', 'c', 'f', 'g'),
            Tuple4('a', 'c', 'f', 'h'),
            Tuple4('a', 'd', 'e', 'g'),
            Tuple4('a', 'd', 'e', 'h'),
            Tuple4('a', 'd', 'f', 'g'),
            Tuple4('a', 'd', 'f', 'h'),
            Tuple4('b', 'c', 'e', 'g'),
            Tuple4('b', 'c', 'e', 'h'),
            Tuple4('b', 'c', 'f', 'g'),
            Tuple4('b', 'c', 'f', 'h'),
            Tuple4('b', 'd', 'e', 'g'),
            Tuple4('b', 'd', 'e', 'h'),
            Tuple4('b', 'd', 'f', 'g'),
            Tuple4('b', 'd', 'f', 'h'),
          ],
        ),
      );
    });

    test('five lists', () {
      final list = ['a', 'b'];
      final l2 = ['c', 'd'];
      final l3 = ['e', 'f'];
      final l4 = ['g', 'h'];
      final l5 = ['i', 'j'];
      final result = list.cartesian5(
        l2,
        l3,
        l4,
        l5,
      );
      expect(
        result,
        orderedEquals(
          [
            Tuple5('a', 'c', 'e', 'g', 'i'),
            Tuple5('a', 'c', 'e', 'g', 'j'),
            Tuple5('a', 'c', 'e', 'h', 'i'),
            Tuple5('a', 'c', 'e', 'h', 'j'),
            Tuple5('a', 'c', 'f', 'g', 'i'),
            Tuple5('a', 'c', 'f', 'g', 'j'),
            Tuple5('a', 'c', 'f', 'h', 'i'),
            Tuple5('a', 'c', 'f', 'h', 'j'),
            Tuple5('a', 'd', 'e', 'g', 'i'),
            Tuple5('a', 'd', 'e', 'g', 'j'),
            Tuple5('a', 'd', 'e', 'h', 'i'),
            Tuple5('a', 'd', 'e', 'h', 'j'),
            Tuple5('a', 'd', 'f', 'g', 'i'),
            Tuple5('a', 'd', 'f', 'g', 'j'),
            Tuple5('a', 'd', 'f', 'h', 'i'),
            Tuple5('a', 'd', 'f', 'h', 'j'),
            Tuple5('b', 'c', 'e', 'g', 'i'),
            Tuple5('b', 'c', 'e', 'g', 'j'),
            Tuple5('b', 'c', 'e', 'h', 'i'),
            Tuple5('b', 'c', 'e', 'h', 'j'),
            Tuple5('b', 'c', 'f', 'g', 'i'),
            Tuple5('b', 'c', 'f', 'g', 'j'),
            Tuple5('b', 'c', 'f', 'h', 'i'),
            Tuple5('b', 'c', 'f', 'h', 'j'),
            Tuple5('b', 'd', 'e', 'g', 'i'),
            Tuple5('b', 'd', 'e', 'g', 'j'),
            Tuple5('b', 'd', 'e', 'h', 'i'),
            Tuple5('b', 'd', 'e', 'h', 'j'),
            Tuple5('b', 'd', 'f', 'g', 'i'),
            Tuple5('b', 'd', 'f', 'g', 'j'),
            Tuple5('b', 'd', 'f', 'h', 'i'),
            Tuple5('b', 'd', 'f', 'h', 'j'),
          ],
        ),
      );
    });

    test('six lists', () {
      final list = ['a', 'b'];
      final l2 = ['c', 'd'];
      final l3 = ['e', 'f'];
      final l4 = ['g', 'h'];
      final l5 = ['i', 'j'];
      final l6 = ['k', 'l'];
      final result = list.cartesian6(
        l2,
        l3,
        l4,
        l5,
        l6,
      );
      expect(
        result,
        orderedEquals(
          [
            Tuple6('a', 'c', 'e', 'g', 'i', 'k'),
            Tuple6('a', 'c', 'e', 'g', 'i', 'l'),
            Tuple6('a', 'c', 'e', 'g', 'j', 'k'),
            Tuple6('a', 'c', 'e', 'g', 'j', 'l'),
            Tuple6('a', 'c', 'e', 'h', 'i', 'k'),
            Tuple6('a', 'c', 'e', 'h', 'i', 'l'),
            Tuple6('a', 'c', 'e', 'h', 'j', 'k'),
            Tuple6('a', 'c', 'e', 'h', 'j', 'l'),
            Tuple6('a', 'c', 'f', 'g', 'i', 'k'),
            Tuple6('a', 'c', 'f', 'g', 'i', 'l'),
            Tuple6('a', 'c', 'f', 'g', 'j', 'k'),
            Tuple6('a', 'c', 'f', 'g', 'j', 'l'),
            Tuple6('a', 'c', 'f', 'h', 'i', 'k'),
            Tuple6('a', 'c', 'f', 'h', 'i', 'l'),
            Tuple6('a', 'c', 'f', 'h', 'j', 'k'),
            Tuple6('a', 'c', 'f', 'h', 'j', 'l'),
            Tuple6('a', 'd', 'e', 'g', 'i', 'k'),
            Tuple6('a', 'd', 'e', 'g', 'i', 'l'),
            Tuple6('a', 'd', 'e', 'g', 'j', 'k'),
            Tuple6('a', 'd', 'e', 'g', 'j', 'l'),
            Tuple6('a', 'd', 'e', 'h', 'i', 'k'),
            Tuple6('a', 'd', 'e', 'h', 'i', 'l'),
            Tuple6('a', 'd', 'e', 'h', 'j', 'k'),
            Tuple6('a', 'd', 'e', 'h', 'j', 'l'),
            Tuple6('a', 'd', 'f', 'g', 'i', 'k'),
            Tuple6('a', 'd', 'f', 'g', 'i', 'l'),
            Tuple6('a', 'd', 'f', 'g', 'j', 'k'),
            Tuple6('a', 'd', 'f', 'g', 'j', 'l'),
            Tuple6('a', 'd', 'f', 'h', 'i', 'k'),
            Tuple6('a', 'd', 'f', 'h', 'i', 'l'),
            Tuple6('a', 'd', 'f', 'h', 'j', 'k'),
            Tuple6('a', 'd', 'f', 'h', 'j', 'l'),
            Tuple6('b', 'c', 'e', 'g', 'i', 'k'),
            Tuple6('b', 'c', 'e', 'g', 'i', 'l'),
            Tuple6('b', 'c', 'e', 'g', 'j', 'k'),
            Tuple6('b', 'c', 'e', 'g', 'j', 'l'),
            Tuple6('b', 'c', 'e', 'h', 'i', 'k'),
            Tuple6('b', 'c', 'e', 'h', 'i', 'l'),
            Tuple6('b', 'c', 'e', 'h', 'j', 'k'),
            Tuple6('b', 'c', 'e', 'h', 'j', 'l'),
            Tuple6('b', 'c', 'f', 'g', 'i', 'k'),
            Tuple6('b', 'c', 'f', 'g', 'i', 'l'),
            Tuple6('b', 'c', 'f', 'g', 'j', 'k'),
            Tuple6('b', 'c', 'f', 'g', 'j', 'l'),
            Tuple6('b', 'c', 'f', 'h', 'i', 'k'),
            Tuple6('b', 'c', 'f', 'h', 'i', 'l'),
            Tuple6('b', 'c', 'f', 'h', 'j', 'k'),
            Tuple6('b', 'c', 'f', 'h', 'j', 'l'),
            Tuple6('b', 'd', 'e', 'g', 'i', 'k'),
            Tuple6('b', 'd', 'e', 'g', 'i', 'l'),
            Tuple6('b', 'd', 'e', 'g', 'j', 'k'),
            Tuple6('b', 'd', 'e', 'g', 'j', 'l'),
            Tuple6('b', 'd', 'e', 'h', 'i', 'k'),
            Tuple6('b', 'd', 'e', 'h', 'i', 'l'),
            Tuple6('b', 'd', 'e', 'h', 'j', 'k'),
            Tuple6('b', 'd', 'e', 'h', 'j', 'l'),
            Tuple6('b', 'd', 'f', 'g', 'i', 'k'),
            Tuple6('b', 'd', 'f', 'g', 'i', 'l'),
            Tuple6('b', 'd', 'f', 'g', 'j', 'k'),
            Tuple6('b', 'd', 'f', 'g', 'j', 'l'),
            Tuple6('b', 'd', 'f', 'h', 'i', 'k'),
            Tuple6('b', 'd', 'f', 'h', 'i', 'l'),
            Tuple6('b', 'd', 'f', 'h', 'j', 'k'),
            Tuple6('b', 'd', 'f', 'h', 'j', 'l'),
          ],
        ),
      );
    });

    test('seven lists', () {
      final list = ['a', 'b'];
      final l2 = ['c', 'd'];
      final l3 = ['e', 'f'];
      final l4 = ['g', 'h'];
      final l5 = ['i', 'j'];
      final l6 = ['k', 'l'];
      final l7 = ['m', 'n'];
      final result = list.cartesian7(
        l2,
        l3,
        l4,
        l5,
        l6,
        l7,
      );
      expect(
        result,
        orderedEquals(
          [
            Tuple7('a', 'c', 'e', 'g', 'i', 'k', 'm'),
            Tuple7('a', 'c', 'e', 'g', 'i', 'k', 'n'),
            Tuple7('a', 'c', 'e', 'g', 'i', 'l', 'm'),
            Tuple7('a', 'c', 'e', 'g', 'i', 'l', 'n'),
            Tuple7('a', 'c', 'e', 'g', 'j', 'k', 'm'),
            Tuple7('a', 'c', 'e', 'g', 'j', 'k', 'n'),
            Tuple7('a', 'c', 'e', 'g', 'j', 'l', 'm'),
            Tuple7('a', 'c', 'e', 'g', 'j', 'l', 'n'),
            Tuple7('a', 'c', 'e', 'h', 'i', 'k', 'm'),
            Tuple7('a', 'c', 'e', 'h', 'i', 'k', 'n'),
            Tuple7('a', 'c', 'e', 'h', 'i', 'l', 'm'),
            Tuple7('a', 'c', 'e', 'h', 'i', 'l', 'n'),
            Tuple7('a', 'c', 'e', 'h', 'j', 'k', 'm'),
            Tuple7('a', 'c', 'e', 'h', 'j', 'k', 'n'),
            Tuple7('a', 'c', 'e', 'h', 'j', 'l', 'm'),
            Tuple7('a', 'c', 'e', 'h', 'j', 'l', 'n'),
            Tuple7('a', 'c', 'f', 'g', 'i', 'k', 'm'),
            Tuple7('a', 'c', 'f', 'g', 'i', 'k', 'n'),
            Tuple7('a', 'c', 'f', 'g', 'i', 'l', 'm'),
            Tuple7('a', 'c', 'f', 'g', 'i', 'l', 'n'),
            Tuple7('a', 'c', 'f', 'g', 'j', 'k', 'm'),
            Tuple7('a', 'c', 'f', 'g', 'j', 'k', 'n'),
            Tuple7('a', 'c', 'f', 'g', 'j', 'l', 'm'),
            Tuple7('a', 'c', 'f', 'g', 'j', 'l', 'n'),
            Tuple7('a', 'c', 'f', 'h', 'i', 'k', 'm'),
            Tuple7('a', 'c', 'f', 'h', 'i', 'k', 'n'),
            Tuple7('a', 'c', 'f', 'h', 'i', 'l', 'm'),
            Tuple7('a', 'c', 'f', 'h', 'i', 'l', 'n'),
            Tuple7('a', 'c', 'f', 'h', 'j', 'k', 'm'),
            Tuple7('a', 'c', 'f', 'h', 'j', 'k', 'n'),
            Tuple7('a', 'c', 'f', 'h', 'j', 'l', 'm'),
            Tuple7('a', 'c', 'f', 'h', 'j', 'l', 'n'),
            Tuple7('a', 'd', 'e', 'g', 'i', 'k', 'm'),
            Tuple7('a', 'd', 'e', 'g', 'i', 'k', 'n'),
            Tuple7('a', 'd', 'e', 'g', 'i', 'l', 'm'),
            Tuple7('a', 'd', 'e', 'g', 'i', 'l', 'n'),
            Tuple7('a', 'd', 'e', 'g', 'j', 'k', 'm'),
            Tuple7('a', 'd', 'e', 'g', 'j', 'k', 'n'),
            Tuple7('a', 'd', 'e', 'g', 'j', 'l', 'm'),
            Tuple7('a', 'd', 'e', 'g', 'j', 'l', 'n'),
            Tuple7('a', 'd', 'e', 'h', 'i', 'k', 'm'),
            Tuple7('a', 'd', 'e', 'h', 'i', 'k', 'n'),
            Tuple7('a', 'd', 'e', 'h', 'i', 'l', 'm'),
            Tuple7('a', 'd', 'e', 'h', 'i', 'l', 'n'),
            Tuple7('a', 'd', 'e', 'h', 'j', 'k', 'm'),
            Tuple7('a', 'd', 'e', 'h', 'j', 'k', 'n'),
            Tuple7('a', 'd', 'e', 'h', 'j', 'l', 'm'),
            Tuple7('a', 'd', 'e', 'h', 'j', 'l', 'n'),
            Tuple7('a', 'd', 'f', 'g', 'i', 'k', 'm'),
            Tuple7('a', 'd', 'f', 'g', 'i', 'k', 'n'),
            Tuple7('a', 'd', 'f', 'g', 'i', 'l', 'm'),
            Tuple7('a', 'd', 'f', 'g', 'i', 'l', 'n'),
            Tuple7('a', 'd', 'f', 'g', 'j', 'k', 'm'),
            Tuple7('a', 'd', 'f', 'g', 'j', 'k', 'n'),
            Tuple7('a', 'd', 'f', 'g', 'j', 'l', 'm'),
            Tuple7('a', 'd', 'f', 'g', 'j', 'l', 'n'),
            Tuple7('a', 'd', 'f', 'h', 'i', 'k', 'm'),
            Tuple7('a', 'd', 'f', 'h', 'i', 'k', 'n'),
            Tuple7('a', 'd', 'f', 'h', 'i', 'l', 'm'),
            Tuple7('a', 'd', 'f', 'h', 'i', 'l', 'n'),
            Tuple7('a', 'd', 'f', 'h', 'j', 'k', 'm'),
            Tuple7('a', 'd', 'f', 'h', 'j', 'k', 'n'),
            Tuple7('a', 'd', 'f', 'h', 'j', 'l', 'm'),
            Tuple7('a', 'd', 'f', 'h', 'j', 'l', 'n'),
            Tuple7('b', 'c', 'e', 'g', 'i', 'k', 'm'),
            Tuple7('b', 'c', 'e', 'g', 'i', 'k', 'n'),
            Tuple7('b', 'c', 'e', 'g', 'i', 'l', 'm'),
            Tuple7('b', 'c', 'e', 'g', 'i', 'l', 'n'),
            Tuple7('b', 'c', 'e', 'g', 'j', 'k', 'm'),
            Tuple7('b', 'c', 'e', 'g', 'j', 'k', 'n'),
            Tuple7('b', 'c', 'e', 'g', 'j', 'l', 'm'),
            Tuple7('b', 'c', 'e', 'g', 'j', 'l', 'n'),
            Tuple7('b', 'c', 'e', 'h', 'i', 'k', 'm'),
            Tuple7('b', 'c', 'e', 'h', 'i', 'k', 'n'),
            Tuple7('b', 'c', 'e', 'h', 'i', 'l', 'm'),
            Tuple7('b', 'c', 'e', 'h', 'i', 'l', 'n'),
            Tuple7('b', 'c', 'e', 'h', 'j', 'k', 'm'),
            Tuple7('b', 'c', 'e', 'h', 'j', 'k', 'n'),
            Tuple7('b', 'c', 'e', 'h', 'j', 'l', 'm'),
            Tuple7('b', 'c', 'e', 'h', 'j', 'l', 'n'),
            Tuple7('b', 'c', 'f', 'g', 'i', 'k', 'm'),
            Tuple7('b', 'c', 'f', 'g', 'i', 'k', 'n'),
            Tuple7('b', 'c', 'f', 'g', 'i', 'l', 'm'),
            Tuple7('b', 'c', 'f', 'g', 'i', 'l', 'n'),
            Tuple7('b', 'c', 'f', 'g', 'j', 'k', 'm'),
            Tuple7('b', 'c', 'f', 'g', 'j', 'k', 'n'),
            Tuple7('b', 'c', 'f', 'g', 'j', 'l', 'm'),
            Tuple7('b', 'c', 'f', 'g', 'j', 'l', 'n'),
            Tuple7('b', 'c', 'f', 'h', 'i', 'k', 'm'),
            Tuple7('b', 'c', 'f', 'h', 'i', 'k', 'n'),
            Tuple7('b', 'c', 'f', 'h', 'i', 'l', 'm'),
            Tuple7('b', 'c', 'f', 'h', 'i', 'l', 'n'),
            Tuple7('b', 'c', 'f', 'h', 'j', 'k', 'm'),
            Tuple7('b', 'c', 'f', 'h', 'j', 'k', 'n'),
            Tuple7('b', 'c', 'f', 'h', 'j', 'l', 'm'),
            Tuple7('b', 'c', 'f', 'h', 'j', 'l', 'n'),
            Tuple7('b', 'd', 'e', 'g', 'i', 'k', 'm'),
            Tuple7('b', 'd', 'e', 'g', 'i', 'k', 'n'),
            Tuple7('b', 'd', 'e', 'g', 'i', 'l', 'm'),
            Tuple7('b', 'd', 'e', 'g', 'i', 'l', 'n'),
            Tuple7('b', 'd', 'e', 'g', 'j', 'k', 'm'),
            Tuple7('b', 'd', 'e', 'g', 'j', 'k', 'n'),
            Tuple7('b', 'd', 'e', 'g', 'j', 'l', 'm'),
            Tuple7('b', 'd', 'e', 'g', 'j', 'l', 'n'),
            Tuple7('b', 'd', 'e', 'h', 'i', 'k', 'm'),
            Tuple7('b', 'd', 'e', 'h', 'i', 'k', 'n'),
            Tuple7('b', 'd', 'e', 'h', 'i', 'l', 'm'),
            Tuple7('b', 'd', 'e', 'h', 'i', 'l', 'n'),
            Tuple7('b', 'd', 'e', 'h', 'j', 'k', 'm'),
            Tuple7('b', 'd', 'e', 'h', 'j', 'k', 'n'),
            Tuple7('b', 'd', 'e', 'h', 'j', 'l', 'm'),
            Tuple7('b', 'd', 'e', 'h', 'j', 'l', 'n'),
            Tuple7('b', 'd', 'f', 'g', 'i', 'k', 'm'),
            Tuple7('b', 'd', 'f', 'g', 'i', 'k', 'n'),
            Tuple7('b', 'd', 'f', 'g', 'i', 'l', 'm'),
            Tuple7('b', 'd', 'f', 'g', 'i', 'l', 'n'),
            Tuple7('b', 'd', 'f', 'g', 'j', 'k', 'm'),
            Tuple7('b', 'd', 'f', 'g', 'j', 'k', 'n'),
            Tuple7('b', 'd', 'f', 'g', 'j', 'l', 'm'),
            Tuple7('b', 'd', 'f', 'g', 'j', 'l', 'n'),
            Tuple7('b', 'd', 'f', 'h', 'i', 'k', 'm'),
            Tuple7('b', 'd', 'f', 'h', 'i', 'k', 'n'),
            Tuple7('b', 'd', 'f', 'h', 'i', 'l', 'm'),
            Tuple7('b', 'd', 'f', 'h', 'i', 'l', 'n'),
            Tuple7('b', 'd', 'f', 'h', 'j', 'k', 'm'),
            Tuple7('b', 'd', 'f', 'h', 'j', 'k', 'n'),
            Tuple7('b', 'd', 'f', 'h', 'j', 'l', 'm'),
            Tuple7('b', 'd', 'f', 'h', 'j', 'l', 'n'),
          ],
        ),
      );
    });

    test('eight lists', () {
      final list = ['a', 'b'];
      final l2 = ['c', 'd'];
      final l3 = ['e', 'f'];
      final l4 = ['g', 'h'];
      final l5 = ['i', 'j'];
      final l6 = ['k', 'l'];
      final l7 = ['m', 'n'];
      final l8 = ['o', 'p'];
      final result = list.cartesian8(
        l2,
        l3,
        l4,
        l5,
        l6,
        l7,
        l8,
      );
      expect(
        result,
        orderedEquals(
          [
            Tuple8('a', 'c', 'e', 'g', 'i', 'k', 'm', 'o'),
            Tuple8('a', 'c', 'e', 'g', 'i', 'k', 'm', 'p'),
            Tuple8('a', 'c', 'e', 'g', 'i', 'k', 'n', 'o'),
            Tuple8('a', 'c', 'e', 'g', 'i', 'k', 'n', 'p'),
            Tuple8('a', 'c', 'e', 'g', 'i', 'l', 'm', 'o'),
            Tuple8('a', 'c', 'e', 'g', 'i', 'l', 'm', 'p'),
            Tuple8('a', 'c', 'e', 'g', 'i', 'l', 'n', 'o'),
            Tuple8('a', 'c', 'e', 'g', 'i', 'l', 'n', 'p'),
            Tuple8('a', 'c', 'e', 'g', 'j', 'k', 'm', 'o'),
            Tuple8('a', 'c', 'e', 'g', 'j', 'k', 'm', 'p'),
            Tuple8('a', 'c', 'e', 'g', 'j', 'k', 'n', 'o'),
            Tuple8('a', 'c', 'e', 'g', 'j', 'k', 'n', 'p'),
            Tuple8('a', 'c', 'e', 'g', 'j', 'l', 'm', 'o'),
            Tuple8('a', 'c', 'e', 'g', 'j', 'l', 'm', 'p'),
            Tuple8('a', 'c', 'e', 'g', 'j', 'l', 'n', 'o'),
            Tuple8('a', 'c', 'e', 'g', 'j', 'l', 'n', 'p'),
            Tuple8('a', 'c', 'e', 'h', 'i', 'k', 'm', 'o'),
            Tuple8('a', 'c', 'e', 'h', 'i', 'k', 'm', 'p'),
            Tuple8('a', 'c', 'e', 'h', 'i', 'k', 'n', 'o'),
            Tuple8('a', 'c', 'e', 'h', 'i', 'k', 'n', 'p'),
            Tuple8('a', 'c', 'e', 'h', 'i', 'l', 'm', 'o'),
            Tuple8('a', 'c', 'e', 'h', 'i', 'l', 'm', 'p'),
            Tuple8('a', 'c', 'e', 'h', 'i', 'l', 'n', 'o'),
            Tuple8('a', 'c', 'e', 'h', 'i', 'l', 'n', 'p'),
            Tuple8('a', 'c', 'e', 'h', 'j', 'k', 'm', 'o'),
            Tuple8('a', 'c', 'e', 'h', 'j', 'k', 'm', 'p'),
            Tuple8('a', 'c', 'e', 'h', 'j', 'k', 'n', 'o'),
            Tuple8('a', 'c', 'e', 'h', 'j', 'k', 'n', 'p'),
            Tuple8('a', 'c', 'e', 'h', 'j', 'l', 'm', 'o'),
            Tuple8('a', 'c', 'e', 'h', 'j', 'l', 'm', 'p'),
            Tuple8('a', 'c', 'e', 'h', 'j', 'l', 'n', 'o'),
            Tuple8('a', 'c', 'e', 'h', 'j', 'l', 'n', 'p'),
            Tuple8('a', 'c', 'f', 'g', 'i', 'k', 'm', 'o'),
            Tuple8('a', 'c', 'f', 'g', 'i', 'k', 'm', 'p'),
            Tuple8('a', 'c', 'f', 'g', 'i', 'k', 'n', 'o'),
            Tuple8('a', 'c', 'f', 'g', 'i', 'k', 'n', 'p'),
            Tuple8('a', 'c', 'f', 'g', 'i', 'l', 'm', 'o'),
            Tuple8('a', 'c', 'f', 'g', 'i', 'l', 'm', 'p'),
            Tuple8('a', 'c', 'f', 'g', 'i', 'l', 'n', 'o'),
            Tuple8('a', 'c', 'f', 'g', 'i', 'l', 'n', 'p'),
            Tuple8('a', 'c', 'f', 'g', 'j', 'k', 'm', 'o'),
            Tuple8('a', 'c', 'f', 'g', 'j', 'k', 'm', 'p'),
            Tuple8('a', 'c', 'f', 'g', 'j', 'k', 'n', 'o'),
            Tuple8('a', 'c', 'f', 'g', 'j', 'k', 'n', 'p'),
            Tuple8('a', 'c', 'f', 'g', 'j', 'l', 'm', 'o'),
            Tuple8('a', 'c', 'f', 'g', 'j', 'l', 'm', 'p'),
            Tuple8('a', 'c', 'f', 'g', 'j', 'l', 'n', 'o'),
            Tuple8('a', 'c', 'f', 'g', 'j', 'l', 'n', 'p'),
            Tuple8('a', 'c', 'f', 'h', 'i', 'k', 'm', 'o'),
            Tuple8('a', 'c', 'f', 'h', 'i', 'k', 'm', 'p'),
            Tuple8('a', 'c', 'f', 'h', 'i', 'k', 'n', 'o'),
            Tuple8('a', 'c', 'f', 'h', 'i', 'k', 'n', 'p'),
            Tuple8('a', 'c', 'f', 'h', 'i', 'l', 'm', 'o'),
            Tuple8('a', 'c', 'f', 'h', 'i', 'l', 'm', 'p'),
            Tuple8('a', 'c', 'f', 'h', 'i', 'l', 'n', 'o'),
            Tuple8('a', 'c', 'f', 'h', 'i', 'l', 'n', 'p'),
            Tuple8('a', 'c', 'f', 'h', 'j', 'k', 'm', 'o'),
            Tuple8('a', 'c', 'f', 'h', 'j', 'k', 'm', 'p'),
            Tuple8('a', 'c', 'f', 'h', 'j', 'k', 'n', 'o'),
            Tuple8('a', 'c', 'f', 'h', 'j', 'k', 'n', 'p'),
            Tuple8('a', 'c', 'f', 'h', 'j', 'l', 'm', 'o'),
            Tuple8('a', 'c', 'f', 'h', 'j', 'l', 'm', 'p'),
            Tuple8('a', 'c', 'f', 'h', 'j', 'l', 'n', 'o'),
            Tuple8('a', 'c', 'f', 'h', 'j', 'l', 'n', 'p'),
            Tuple8('a', 'd', 'e', 'g', 'i', 'k', 'm', 'o'),
            Tuple8('a', 'd', 'e', 'g', 'i', 'k', 'm', 'p'),
            Tuple8('a', 'd', 'e', 'g', 'i', 'k', 'n', 'o'),
            Tuple8('a', 'd', 'e', 'g', 'i', 'k', 'n', 'p'),
            Tuple8('a', 'd', 'e', 'g', 'i', 'l', 'm', 'o'),
            Tuple8('a', 'd', 'e', 'g', 'i', 'l', 'm', 'p'),
            Tuple8('a', 'd', 'e', 'g', 'i', 'l', 'n', 'o'),
            Tuple8('a', 'd', 'e', 'g', 'i', 'l', 'n', 'p'),
            Tuple8('a', 'd', 'e', 'g', 'j', 'k', 'm', 'o'),
            Tuple8('a', 'd', 'e', 'g', 'j', 'k', 'm', 'p'),
            Tuple8('a', 'd', 'e', 'g', 'j', 'k', 'n', 'o'),
            Tuple8('a', 'd', 'e', 'g', 'j', 'k', 'n', 'p'),
            Tuple8('a', 'd', 'e', 'g', 'j', 'l', 'm', 'o'),
            Tuple8('a', 'd', 'e', 'g', 'j', 'l', 'm', 'p'),
            Tuple8('a', 'd', 'e', 'g', 'j', 'l', 'n', 'o'),
            Tuple8('a', 'd', 'e', 'g', 'j', 'l', 'n', 'p'),
            Tuple8('a', 'd', 'e', 'h', 'i', 'k', 'm', 'o'),
            Tuple8('a', 'd', 'e', 'h', 'i', 'k', 'm', 'p'),
            Tuple8('a', 'd', 'e', 'h', 'i', 'k', 'n', 'o'),
            Tuple8('a', 'd', 'e', 'h', 'i', 'k', 'n', 'p'),
            Tuple8('a', 'd', 'e', 'h', 'i', 'l', 'm', 'o'),
            Tuple8('a', 'd', 'e', 'h', 'i', 'l', 'm', 'p'),
            Tuple8('a', 'd', 'e', 'h', 'i', 'l', 'n', 'o'),
            Tuple8('a', 'd', 'e', 'h', 'i', 'l', 'n', 'p'),
            Tuple8('a', 'd', 'e', 'h', 'j', 'k', 'm', 'o'),
            Tuple8('a', 'd', 'e', 'h', 'j', 'k', 'm', 'p'),
            Tuple8('a', 'd', 'e', 'h', 'j', 'k', 'n', 'o'),
            Tuple8('a', 'd', 'e', 'h', 'j', 'k', 'n', 'p'),
            Tuple8('a', 'd', 'e', 'h', 'j', 'l', 'm', 'o'),
            Tuple8('a', 'd', 'e', 'h', 'j', 'l', 'm', 'p'),
            Tuple8('a', 'd', 'e', 'h', 'j', 'l', 'n', 'o'),
            Tuple8('a', 'd', 'e', 'h', 'j', 'l', 'n', 'p'),
            Tuple8('a', 'd', 'f', 'g', 'i', 'k', 'm', 'o'),
            Tuple8('a', 'd', 'f', 'g', 'i', 'k', 'm', 'p'),
            Tuple8('a', 'd', 'f', 'g', 'i', 'k', 'n', 'o'),
            Tuple8('a', 'd', 'f', 'g', 'i', 'k', 'n', 'p'),
            Tuple8('a', 'd', 'f', 'g', 'i', 'l', 'm', 'o'),
            Tuple8('a', 'd', 'f', 'g', 'i', 'l', 'm', 'p'),
            Tuple8('a', 'd', 'f', 'g', 'i', 'l', 'n', 'o'),
            Tuple8('a', 'd', 'f', 'g', 'i', 'l', 'n', 'p'),
            Tuple8('a', 'd', 'f', 'g', 'j', 'k', 'm', 'o'),
            Tuple8('a', 'd', 'f', 'g', 'j', 'k', 'm', 'p'),
            Tuple8('a', 'd', 'f', 'g', 'j', 'k', 'n', 'o'),
            Tuple8('a', 'd', 'f', 'g', 'j', 'k', 'n', 'p'),
            Tuple8('a', 'd', 'f', 'g', 'j', 'l', 'm', 'o'),
            Tuple8('a', 'd', 'f', 'g', 'j', 'l', 'm', 'p'),
            Tuple8('a', 'd', 'f', 'g', 'j', 'l', 'n', 'o'),
            Tuple8('a', 'd', 'f', 'g', 'j', 'l', 'n', 'p'),
            Tuple8('a', 'd', 'f', 'h', 'i', 'k', 'm', 'o'),
            Tuple8('a', 'd', 'f', 'h', 'i', 'k', 'm', 'p'),
            Tuple8('a', 'd', 'f', 'h', 'i', 'k', 'n', 'o'),
            Tuple8('a', 'd', 'f', 'h', 'i', 'k', 'n', 'p'),
            Tuple8('a', 'd', 'f', 'h', 'i', 'l', 'm', 'o'),
            Tuple8('a', 'd', 'f', 'h', 'i', 'l', 'm', 'p'),
            Tuple8('a', 'd', 'f', 'h', 'i', 'l', 'n', 'o'),
            Tuple8('a', 'd', 'f', 'h', 'i', 'l', 'n', 'p'),
            Tuple8('a', 'd', 'f', 'h', 'j', 'k', 'm', 'o'),
            Tuple8('a', 'd', 'f', 'h', 'j', 'k', 'm', 'p'),
            Tuple8('a', 'd', 'f', 'h', 'j', 'k', 'n', 'o'),
            Tuple8('a', 'd', 'f', 'h', 'j', 'k', 'n', 'p'),
            Tuple8('a', 'd', 'f', 'h', 'j', 'l', 'm', 'o'),
            Tuple8('a', 'd', 'f', 'h', 'j', 'l', 'm', 'p'),
            Tuple8('a', 'd', 'f', 'h', 'j', 'l', 'n', 'o'),
            Tuple8('a', 'd', 'f', 'h', 'j', 'l', 'n', 'p'),
            Tuple8('b', 'c', 'e', 'g', 'i', 'k', 'm', 'o'),
            Tuple8('b', 'c', 'e', 'g', 'i', 'k', 'm', 'p'),
            Tuple8('b', 'c', 'e', 'g', 'i', 'k', 'n', 'o'),
            Tuple8('b', 'c', 'e', 'g', 'i', 'k', 'n', 'p'),
            Tuple8('b', 'c', 'e', 'g', 'i', 'l', 'm', 'o'),
            Tuple8('b', 'c', 'e', 'g', 'i', 'l', 'm', 'p'),
            Tuple8('b', 'c', 'e', 'g', 'i', 'l', 'n', 'o'),
            Tuple8('b', 'c', 'e', 'g', 'i', 'l', 'n', 'p'),
            Tuple8('b', 'c', 'e', 'g', 'j', 'k', 'm', 'o'),
            Tuple8('b', 'c', 'e', 'g', 'j', 'k', 'm', 'p'),
            Tuple8('b', 'c', 'e', 'g', 'j', 'k', 'n', 'o'),
            Tuple8('b', 'c', 'e', 'g', 'j', 'k', 'n', 'p'),
            Tuple8('b', 'c', 'e', 'g', 'j', 'l', 'm', 'o'),
            Tuple8('b', 'c', 'e', 'g', 'j', 'l', 'm', 'p'),
            Tuple8('b', 'c', 'e', 'g', 'j', 'l', 'n', 'o'),
            Tuple8('b', 'c', 'e', 'g', 'j', 'l', 'n', 'p'),
            Tuple8('b', 'c', 'e', 'h', 'i', 'k', 'm', 'o'),
            Tuple8('b', 'c', 'e', 'h', 'i', 'k', 'm', 'p'),
            Tuple8('b', 'c', 'e', 'h', 'i', 'k', 'n', 'o'),
            Tuple8('b', 'c', 'e', 'h', 'i', 'k', 'n', 'p'),
            Tuple8('b', 'c', 'e', 'h', 'i', 'l', 'm', 'o'),
            Tuple8('b', 'c', 'e', 'h', 'i', 'l', 'm', 'p'),
            Tuple8('b', 'c', 'e', 'h', 'i', 'l', 'n', 'o'),
            Tuple8('b', 'c', 'e', 'h', 'i', 'l', 'n', 'p'),
            Tuple8('b', 'c', 'e', 'h', 'j', 'k', 'm', 'o'),
            Tuple8('b', 'c', 'e', 'h', 'j', 'k', 'm', 'p'),
            Tuple8('b', 'c', 'e', 'h', 'j', 'k', 'n', 'o'),
            Tuple8('b', 'c', 'e', 'h', 'j', 'k', 'n', 'p'),
            Tuple8('b', 'c', 'e', 'h', 'j', 'l', 'm', 'o'),
            Tuple8('b', 'c', 'e', 'h', 'j', 'l', 'm', 'p'),
            Tuple8('b', 'c', 'e', 'h', 'j', 'l', 'n', 'o'),
            Tuple8('b', 'c', 'e', 'h', 'j', 'l', 'n', 'p'),
            Tuple8('b', 'c', 'f', 'g', 'i', 'k', 'm', 'o'),
            Tuple8('b', 'c', 'f', 'g', 'i', 'k', 'm', 'p'),
            Tuple8('b', 'c', 'f', 'g', 'i', 'k', 'n', 'o'),
            Tuple8('b', 'c', 'f', 'g', 'i', 'k', 'n', 'p'),
            Tuple8('b', 'c', 'f', 'g', 'i', 'l', 'm', 'o'),
            Tuple8('b', 'c', 'f', 'g', 'i', 'l', 'm', 'p'),
            Tuple8('b', 'c', 'f', 'g', 'i', 'l', 'n', 'o'),
            Tuple8('b', 'c', 'f', 'g', 'i', 'l', 'n', 'p'),
            Tuple8('b', 'c', 'f', 'g', 'j', 'k', 'm', 'o'),
            Tuple8('b', 'c', 'f', 'g', 'j', 'k', 'm', 'p'),
            Tuple8('b', 'c', 'f', 'g', 'j', 'k', 'n', 'o'),
            Tuple8('b', 'c', 'f', 'g', 'j', 'k', 'n', 'p'),
            Tuple8('b', 'c', 'f', 'g', 'j', 'l', 'm', 'o'),
            Tuple8('b', 'c', 'f', 'g', 'j', 'l', 'm', 'p'),
            Tuple8('b', 'c', 'f', 'g', 'j', 'l', 'n', 'o'),
            Tuple8('b', 'c', 'f', 'g', 'j', 'l', 'n', 'p'),
            Tuple8('b', 'c', 'f', 'h', 'i', 'k', 'm', 'o'),
            Tuple8('b', 'c', 'f', 'h', 'i', 'k', 'm', 'p'),
            Tuple8('b', 'c', 'f', 'h', 'i', 'k', 'n', 'o'),
            Tuple8('b', 'c', 'f', 'h', 'i', 'k', 'n', 'p'),
            Tuple8('b', 'c', 'f', 'h', 'i', 'l', 'm', 'o'),
            Tuple8('b', 'c', 'f', 'h', 'i', 'l', 'm', 'p'),
            Tuple8('b', 'c', 'f', 'h', 'i', 'l', 'n', 'o'),
            Tuple8('b', 'c', 'f', 'h', 'i', 'l', 'n', 'p'),
            Tuple8('b', 'c', 'f', 'h', 'j', 'k', 'm', 'o'),
            Tuple8('b', 'c', 'f', 'h', 'j', 'k', 'm', 'p'),
            Tuple8('b', 'c', 'f', 'h', 'j', 'k', 'n', 'o'),
            Tuple8('b', 'c', 'f', 'h', 'j', 'k', 'n', 'p'),
            Tuple8('b', 'c', 'f', 'h', 'j', 'l', 'm', 'o'),
            Tuple8('b', 'c', 'f', 'h', 'j', 'l', 'm', 'p'),
            Tuple8('b', 'c', 'f', 'h', 'j', 'l', 'n', 'o'),
            Tuple8('b', 'c', 'f', 'h', 'j', 'l', 'n', 'p'),
            Tuple8('b', 'd', 'e', 'g', 'i', 'k', 'm', 'o'),
            Tuple8('b', 'd', 'e', 'g', 'i', 'k', 'm', 'p'),
            Tuple8('b', 'd', 'e', 'g', 'i', 'k', 'n', 'o'),
            Tuple8('b', 'd', 'e', 'g', 'i', 'k', 'n', 'p'),
            Tuple8('b', 'd', 'e', 'g', 'i', 'l', 'm', 'o'),
            Tuple8('b', 'd', 'e', 'g', 'i', 'l', 'm', 'p'),
            Tuple8('b', 'd', 'e', 'g', 'i', 'l', 'n', 'o'),
            Tuple8('b', 'd', 'e', 'g', 'i', 'l', 'n', 'p'),
            Tuple8('b', 'd', 'e', 'g', 'j', 'k', 'm', 'o'),
            Tuple8('b', 'd', 'e', 'g', 'j', 'k', 'm', 'p'),
            Tuple8('b', 'd', 'e', 'g', 'j', 'k', 'n', 'o'),
            Tuple8('b', 'd', 'e', 'g', 'j', 'k', 'n', 'p'),
            Tuple8('b', 'd', 'e', 'g', 'j', 'l', 'm', 'o'),
            Tuple8('b', 'd', 'e', 'g', 'j', 'l', 'm', 'p'),
            Tuple8('b', 'd', 'e', 'g', 'j', 'l', 'n', 'o'),
            Tuple8('b', 'd', 'e', 'g', 'j', 'l', 'n', 'p'),
            Tuple8('b', 'd', 'e', 'h', 'i', 'k', 'm', 'o'),
            Tuple8('b', 'd', 'e', 'h', 'i', 'k', 'm', 'p'),
            Tuple8('b', 'd', 'e', 'h', 'i', 'k', 'n', 'o'),
            Tuple8('b', 'd', 'e', 'h', 'i', 'k', 'n', 'p'),
            Tuple8('b', 'd', 'e', 'h', 'i', 'l', 'm', 'o'),
            Tuple8('b', 'd', 'e', 'h', 'i', 'l', 'm', 'p'),
            Tuple8('b', 'd', 'e', 'h', 'i', 'l', 'n', 'o'),
            Tuple8('b', 'd', 'e', 'h', 'i', 'l', 'n', 'p'),
            Tuple8('b', 'd', 'e', 'h', 'j', 'k', 'm', 'o'),
            Tuple8('b', 'd', 'e', 'h', 'j', 'k', 'm', 'p'),
            Tuple8('b', 'd', 'e', 'h', 'j', 'k', 'n', 'o'),
            Tuple8('b', 'd', 'e', 'h', 'j', 'k', 'n', 'p'),
            Tuple8('b', 'd', 'e', 'h', 'j', 'l', 'm', 'o'),
            Tuple8('b', 'd', 'e', 'h', 'j', 'l', 'm', 'p'),
            Tuple8('b', 'd', 'e', 'h', 'j', 'l', 'n', 'o'),
            Tuple8('b', 'd', 'e', 'h', 'j', 'l', 'n', 'p'),
            Tuple8('b', 'd', 'f', 'g', 'i', 'k', 'm', 'o'),
            Tuple8('b', 'd', 'f', 'g', 'i', 'k', 'm', 'p'),
            Tuple8('b', 'd', 'f', 'g', 'i', 'k', 'n', 'o'),
            Tuple8('b', 'd', 'f', 'g', 'i', 'k', 'n', 'p'),
            Tuple8('b', 'd', 'f', 'g', 'i', 'l', 'm', 'o'),
            Tuple8('b', 'd', 'f', 'g', 'i', 'l', 'm', 'p'),
            Tuple8('b', 'd', 'f', 'g', 'i', 'l', 'n', 'o'),
            Tuple8('b', 'd', 'f', 'g', 'i', 'l', 'n', 'p'),
            Tuple8('b', 'd', 'f', 'g', 'j', 'k', 'm', 'o'),
            Tuple8('b', 'd', 'f', 'g', 'j', 'k', 'm', 'p'),
            Tuple8('b', 'd', 'f', 'g', 'j', 'k', 'n', 'o'),
            Tuple8('b', 'd', 'f', 'g', 'j', 'k', 'n', 'p'),
            Tuple8('b', 'd', 'f', 'g', 'j', 'l', 'm', 'o'),
            Tuple8('b', 'd', 'f', 'g', 'j', 'l', 'm', 'p'),
            Tuple8('b', 'd', 'f', 'g', 'j', 'l', 'n', 'o'),
            Tuple8('b', 'd', 'f', 'g', 'j', 'l', 'n', 'p'),
            Tuple8('b', 'd', 'f', 'h', 'i', 'k', 'm', 'o'),
            Tuple8('b', 'd', 'f', 'h', 'i', 'k', 'm', 'p'),
            Tuple8('b', 'd', 'f', 'h', 'i', 'k', 'n', 'o'),
            Tuple8('b', 'd', 'f', 'h', 'i', 'k', 'n', 'p'),
            Tuple8('b', 'd', 'f', 'h', 'i', 'l', 'm', 'o'),
            Tuple8('b', 'd', 'f', 'h', 'i', 'l', 'm', 'p'),
            Tuple8('b', 'd', 'f', 'h', 'i', 'l', 'n', 'o'),
            Tuple8('b', 'd', 'f', 'h', 'i', 'l', 'n', 'p'),
            Tuple8('b', 'd', 'f', 'h', 'j', 'k', 'm', 'o'),
            Tuple8('b', 'd', 'f', 'h', 'j', 'k', 'm', 'p'),
            Tuple8('b', 'd', 'f', 'h', 'j', 'k', 'n', 'o'),
            Tuple8('b', 'd', 'f', 'h', 'j', 'k', 'n', 'p'),
            Tuple8('b', 'd', 'f', 'h', 'j', 'l', 'm', 'o'),
            Tuple8('b', 'd', 'f', 'h', 'j', 'l', 'm', 'p'),
            Tuple8('b', 'd', 'f', 'h', 'j', 'l', 'n', 'o'),
            Tuple8('b', 'd', 'f', 'h', 'j', 'l', 'n', 'p'),
          ],
        ),
      );
    });

    test('nine lists', () {
      final list = ['a', 'b'];
      final l2 = ['c', 'd'];
      final l3 = ['e', 'f'];
      final l4 = ['g', 'h'];
      final l5 = ['i', 'j'];
      final l6 = ['k', 'l'];
      final l7 = ['m', 'n'];
      final l8 = ['o', 'p'];
      final l9 = ['q', 'r'];
      final result = list.cartesian9(
        l2,
        l3,
        l4,
        l5,
        l6,
        l7,
        l8,
        l9,
      );
      expect(
        result,
        orderedEquals(
          [
            Tuple9('a', 'c', 'e', 'g', 'i', 'k', 'm', 'o', 'q'),
            Tuple9('a', 'c', 'e', 'g', 'i', 'k', 'm', 'o', 'r'),
            Tuple9('a', 'c', 'e', 'g', 'i', 'k', 'm', 'p', 'q'),
            Tuple9('a', 'c', 'e', 'g', 'i', 'k', 'm', 'p', 'r'),
            Tuple9('a', 'c', 'e', 'g', 'i', 'k', 'n', 'o', 'q'),
            Tuple9('a', 'c', 'e', 'g', 'i', 'k', 'n', 'o', 'r'),
            Tuple9('a', 'c', 'e', 'g', 'i', 'k', 'n', 'p', 'q'),
            Tuple9('a', 'c', 'e', 'g', 'i', 'k', 'n', 'p', 'r'),
            Tuple9('a', 'c', 'e', 'g', 'i', 'l', 'm', 'o', 'q'),
            Tuple9('a', 'c', 'e', 'g', 'i', 'l', 'm', 'o', 'r'),
            Tuple9('a', 'c', 'e', 'g', 'i', 'l', 'm', 'p', 'q'),
            Tuple9('a', 'c', 'e', 'g', 'i', 'l', 'm', 'p', 'r'),
            Tuple9('a', 'c', 'e', 'g', 'i', 'l', 'n', 'o', 'q'),
            Tuple9('a', 'c', 'e', 'g', 'i', 'l', 'n', 'o', 'r'),
            Tuple9('a', 'c', 'e', 'g', 'i', 'l', 'n', 'p', 'q'),
            Tuple9('a', 'c', 'e', 'g', 'i', 'l', 'n', 'p', 'r'),
            Tuple9('a', 'c', 'e', 'g', 'j', 'k', 'm', 'o', 'q'),
            Tuple9('a', 'c', 'e', 'g', 'j', 'k', 'm', 'o', 'r'),
            Tuple9('a', 'c', 'e', 'g', 'j', 'k', 'm', 'p', 'q'),
            Tuple9('a', 'c', 'e', 'g', 'j', 'k', 'm', 'p', 'r'),
            Tuple9('a', 'c', 'e', 'g', 'j', 'k', 'n', 'o', 'q'),
            Tuple9('a', 'c', 'e', 'g', 'j', 'k', 'n', 'o', 'r'),
            Tuple9('a', 'c', 'e', 'g', 'j', 'k', 'n', 'p', 'q'),
            Tuple9('a', 'c', 'e', 'g', 'j', 'k', 'n', 'p', 'r'),
            Tuple9('a', 'c', 'e', 'g', 'j', 'l', 'm', 'o', 'q'),
            Tuple9('a', 'c', 'e', 'g', 'j', 'l', 'm', 'o', 'r'),
            Tuple9('a', 'c', 'e', 'g', 'j', 'l', 'm', 'p', 'q'),
            Tuple9('a', 'c', 'e', 'g', 'j', 'l', 'm', 'p', 'r'),
            Tuple9('a', 'c', 'e', 'g', 'j', 'l', 'n', 'o', 'q'),
            Tuple9('a', 'c', 'e', 'g', 'j', 'l', 'n', 'o', 'r'),
            Tuple9('a', 'c', 'e', 'g', 'j', 'l', 'n', 'p', 'q'),
            Tuple9('a', 'c', 'e', 'g', 'j', 'l', 'n', 'p', 'r'),
            Tuple9('a', 'c', 'e', 'h', 'i', 'k', 'm', 'o', 'q'),
            Tuple9('a', 'c', 'e', 'h', 'i', 'k', 'm', 'o', 'r'),
            Tuple9('a', 'c', 'e', 'h', 'i', 'k', 'm', 'p', 'q'),
            Tuple9('a', 'c', 'e', 'h', 'i', 'k', 'm', 'p', 'r'),
            Tuple9('a', 'c', 'e', 'h', 'i', 'k', 'n', 'o', 'q'),
            Tuple9('a', 'c', 'e', 'h', 'i', 'k', 'n', 'o', 'r'),
            Tuple9('a', 'c', 'e', 'h', 'i', 'k', 'n', 'p', 'q'),
            Tuple9('a', 'c', 'e', 'h', 'i', 'k', 'n', 'p', 'r'),
            Tuple9('a', 'c', 'e', 'h', 'i', 'l', 'm', 'o', 'q'),
            Tuple9('a', 'c', 'e', 'h', 'i', 'l', 'm', 'o', 'r'),
            Tuple9('a', 'c', 'e', 'h', 'i', 'l', 'm', 'p', 'q'),
            Tuple9('a', 'c', 'e', 'h', 'i', 'l', 'm', 'p', 'r'),
            Tuple9('a', 'c', 'e', 'h', 'i', 'l', 'n', 'o', 'q'),
            Tuple9('a', 'c', 'e', 'h', 'i', 'l', 'n', 'o', 'r'),
            Tuple9('a', 'c', 'e', 'h', 'i', 'l', 'n', 'p', 'q'),
            Tuple9('a', 'c', 'e', 'h', 'i', 'l', 'n', 'p', 'r'),
            Tuple9('a', 'c', 'e', 'h', 'j', 'k', 'm', 'o', 'q'),
            Tuple9('a', 'c', 'e', 'h', 'j', 'k', 'm', 'o', 'r'),
            Tuple9('a', 'c', 'e', 'h', 'j', 'k', 'm', 'p', 'q'),
            Tuple9('a', 'c', 'e', 'h', 'j', 'k', 'm', 'p', 'r'),
            Tuple9('a', 'c', 'e', 'h', 'j', 'k', 'n', 'o', 'q'),
            Tuple9('a', 'c', 'e', 'h', 'j', 'k', 'n', 'o', 'r'),
            Tuple9('a', 'c', 'e', 'h', 'j', 'k', 'n', 'p', 'q'),
            Tuple9('a', 'c', 'e', 'h', 'j', 'k', 'n', 'p', 'r'),
            Tuple9('a', 'c', 'e', 'h', 'j', 'l', 'm', 'o', 'q'),
            Tuple9('a', 'c', 'e', 'h', 'j', 'l', 'm', 'o', 'r'),
            Tuple9('a', 'c', 'e', 'h', 'j', 'l', 'm', 'p', 'q'),
            Tuple9('a', 'c', 'e', 'h', 'j', 'l', 'm', 'p', 'r'),
            Tuple9('a', 'c', 'e', 'h', 'j', 'l', 'n', 'o', 'q'),
            Tuple9('a', 'c', 'e', 'h', 'j', 'l', 'n', 'o', 'r'),
            Tuple9('a', 'c', 'e', 'h', 'j', 'l', 'n', 'p', 'q'),
            Tuple9('a', 'c', 'e', 'h', 'j', 'l', 'n', 'p', 'r'),
            Tuple9('a', 'c', 'f', 'g', 'i', 'k', 'm', 'o', 'q'),
            Tuple9('a', 'c', 'f', 'g', 'i', 'k', 'm', 'o', 'r'),
            Tuple9('a', 'c', 'f', 'g', 'i', 'k', 'm', 'p', 'q'),
            Tuple9('a', 'c', 'f', 'g', 'i', 'k', 'm', 'p', 'r'),
            Tuple9('a', 'c', 'f', 'g', 'i', 'k', 'n', 'o', 'q'),
            Tuple9('a', 'c', 'f', 'g', 'i', 'k', 'n', 'o', 'r'),
            Tuple9('a', 'c', 'f', 'g', 'i', 'k', 'n', 'p', 'q'),
            Tuple9('a', 'c', 'f', 'g', 'i', 'k', 'n', 'p', 'r'),
            Tuple9('a', 'c', 'f', 'g', 'i', 'l', 'm', 'o', 'q'),
            Tuple9('a', 'c', 'f', 'g', 'i', 'l', 'm', 'o', 'r'),
            Tuple9('a', 'c', 'f', 'g', 'i', 'l', 'm', 'p', 'q'),
            Tuple9('a', 'c', 'f', 'g', 'i', 'l', 'm', 'p', 'r'),
            Tuple9('a', 'c', 'f', 'g', 'i', 'l', 'n', 'o', 'q'),
            Tuple9('a', 'c', 'f', 'g', 'i', 'l', 'n', 'o', 'r'),
            Tuple9('a', 'c', 'f', 'g', 'i', 'l', 'n', 'p', 'q'),
            Tuple9('a', 'c', 'f', 'g', 'i', 'l', 'n', 'p', 'r'),
            Tuple9('a', 'c', 'f', 'g', 'j', 'k', 'm', 'o', 'q'),
            Tuple9('a', 'c', 'f', 'g', 'j', 'k', 'm', 'o', 'r'),
            Tuple9('a', 'c', 'f', 'g', 'j', 'k', 'm', 'p', 'q'),
            Tuple9('a', 'c', 'f', 'g', 'j', 'k', 'm', 'p', 'r'),
            Tuple9('a', 'c', 'f', 'g', 'j', 'k', 'n', 'o', 'q'),
            Tuple9('a', 'c', 'f', 'g', 'j', 'k', 'n', 'o', 'r'),
            Tuple9('a', 'c', 'f', 'g', 'j', 'k', 'n', 'p', 'q'),
            Tuple9('a', 'c', 'f', 'g', 'j', 'k', 'n', 'p', 'r'),
            Tuple9('a', 'c', 'f', 'g', 'j', 'l', 'm', 'o', 'q'),
            Tuple9('a', 'c', 'f', 'g', 'j', 'l', 'm', 'o', 'r'),
            Tuple9('a', 'c', 'f', 'g', 'j', 'l', 'm', 'p', 'q'),
            Tuple9('a', 'c', 'f', 'g', 'j', 'l', 'm', 'p', 'r'),
            Tuple9('a', 'c', 'f', 'g', 'j', 'l', 'n', 'o', 'q'),
            Tuple9('a', 'c', 'f', 'g', 'j', 'l', 'n', 'o', 'r'),
            Tuple9('a', 'c', 'f', 'g', 'j', 'l', 'n', 'p', 'q'),
            Tuple9('a', 'c', 'f', 'g', 'j', 'l', 'n', 'p', 'r'),
            Tuple9('a', 'c', 'f', 'h', 'i', 'k', 'm', 'o', 'q'),
            Tuple9('a', 'c', 'f', 'h', 'i', 'k', 'm', 'o', 'r'),
            Tuple9('a', 'c', 'f', 'h', 'i', 'k', 'm', 'p', 'q'),
            Tuple9('a', 'c', 'f', 'h', 'i', 'k', 'm', 'p', 'r'),
            Tuple9('a', 'c', 'f', 'h', 'i', 'k', 'n', 'o', 'q'),
            Tuple9('a', 'c', 'f', 'h', 'i', 'k', 'n', 'o', 'r'),
            Tuple9('a', 'c', 'f', 'h', 'i', 'k', 'n', 'p', 'q'),
            Tuple9('a', 'c', 'f', 'h', 'i', 'k', 'n', 'p', 'r'),
            Tuple9('a', 'c', 'f', 'h', 'i', 'l', 'm', 'o', 'q'),
            Tuple9('a', 'c', 'f', 'h', 'i', 'l', 'm', 'o', 'r'),
            Tuple9('a', 'c', 'f', 'h', 'i', 'l', 'm', 'p', 'q'),
            Tuple9('a', 'c', 'f', 'h', 'i', 'l', 'm', 'p', 'r'),
            Tuple9('a', 'c', 'f', 'h', 'i', 'l', 'n', 'o', 'q'),
            Tuple9('a', 'c', 'f', 'h', 'i', 'l', 'n', 'o', 'r'),
            Tuple9('a', 'c', 'f', 'h', 'i', 'l', 'n', 'p', 'q'),
            Tuple9('a', 'c', 'f', 'h', 'i', 'l', 'n', 'p', 'r'),
            Tuple9('a', 'c', 'f', 'h', 'j', 'k', 'm', 'o', 'q'),
            Tuple9('a', 'c', 'f', 'h', 'j', 'k', 'm', 'o', 'r'),
            Tuple9('a', 'c', 'f', 'h', 'j', 'k', 'm', 'p', 'q'),
            Tuple9('a', 'c', 'f', 'h', 'j', 'k', 'm', 'p', 'r'),
            Tuple9('a', 'c', 'f', 'h', 'j', 'k', 'n', 'o', 'q'),
            Tuple9('a', 'c', 'f', 'h', 'j', 'k', 'n', 'o', 'r'),
            Tuple9('a', 'c', 'f', 'h', 'j', 'k', 'n', 'p', 'q'),
            Tuple9('a', 'c', 'f', 'h', 'j', 'k', 'n', 'p', 'r'),
            Tuple9('a', 'c', 'f', 'h', 'j', 'l', 'm', 'o', 'q'),
            Tuple9('a', 'c', 'f', 'h', 'j', 'l', 'm', 'o', 'r'),
            Tuple9('a', 'c', 'f', 'h', 'j', 'l', 'm', 'p', 'q'),
            Tuple9('a', 'c', 'f', 'h', 'j', 'l', 'm', 'p', 'r'),
            Tuple9('a', 'c', 'f', 'h', 'j', 'l', 'n', 'o', 'q'),
            Tuple9('a', 'c', 'f', 'h', 'j', 'l', 'n', 'o', 'r'),
            Tuple9('a', 'c', 'f', 'h', 'j', 'l', 'n', 'p', 'q'),
            Tuple9('a', 'c', 'f', 'h', 'j', 'l', 'n', 'p', 'r'),
            Tuple9('a', 'd', 'e', 'g', 'i', 'k', 'm', 'o', 'q'),
            Tuple9('a', 'd', 'e', 'g', 'i', 'k', 'm', 'o', 'r'),
            Tuple9('a', 'd', 'e', 'g', 'i', 'k', 'm', 'p', 'q'),
            Tuple9('a', 'd', 'e', 'g', 'i', 'k', 'm', 'p', 'r'),
            Tuple9('a', 'd', 'e', 'g', 'i', 'k', 'n', 'o', 'q'),
            Tuple9('a', 'd', 'e', 'g', 'i', 'k', 'n', 'o', 'r'),
            Tuple9('a', 'd', 'e', 'g', 'i', 'k', 'n', 'p', 'q'),
            Tuple9('a', 'd', 'e', 'g', 'i', 'k', 'n', 'p', 'r'),
            Tuple9('a', 'd', 'e', 'g', 'i', 'l', 'm', 'o', 'q'),
            Tuple9('a', 'd', 'e', 'g', 'i', 'l', 'm', 'o', 'r'),
            Tuple9('a', 'd', 'e', 'g', 'i', 'l', 'm', 'p', 'q'),
            Tuple9('a', 'd', 'e', 'g', 'i', 'l', 'm', 'p', 'r'),
            Tuple9('a', 'd', 'e', 'g', 'i', 'l', 'n', 'o', 'q'),
            Tuple9('a', 'd', 'e', 'g', 'i', 'l', 'n', 'o', 'r'),
            Tuple9('a', 'd', 'e', 'g', 'i', 'l', 'n', 'p', 'q'),
            Tuple9('a', 'd', 'e', 'g', 'i', 'l', 'n', 'p', 'r'),
            Tuple9('a', 'd', 'e', 'g', 'j', 'k', 'm', 'o', 'q'),
            Tuple9('a', 'd', 'e', 'g', 'j', 'k', 'm', 'o', 'r'),
            Tuple9('a', 'd', 'e', 'g', 'j', 'k', 'm', 'p', 'q'),
            Tuple9('a', 'd', 'e', 'g', 'j', 'k', 'm', 'p', 'r'),
            Tuple9('a', 'd', 'e', 'g', 'j', 'k', 'n', 'o', 'q'),
            Tuple9('a', 'd', 'e', 'g', 'j', 'k', 'n', 'o', 'r'),
            Tuple9('a', 'd', 'e', 'g', 'j', 'k', 'n', 'p', 'q'),
            Tuple9('a', 'd', 'e', 'g', 'j', 'k', 'n', 'p', 'r'),
            Tuple9('a', 'd', 'e', 'g', 'j', 'l', 'm', 'o', 'q'),
            Tuple9('a', 'd', 'e', 'g', 'j', 'l', 'm', 'o', 'r'),
            Tuple9('a', 'd', 'e', 'g', 'j', 'l', 'm', 'p', 'q'),
            Tuple9('a', 'd', 'e', 'g', 'j', 'l', 'm', 'p', 'r'),
            Tuple9('a', 'd', 'e', 'g', 'j', 'l', 'n', 'o', 'q'),
            Tuple9('a', 'd', 'e', 'g', 'j', 'l', 'n', 'o', 'r'),
            Tuple9('a', 'd', 'e', 'g', 'j', 'l', 'n', 'p', 'q'),
            Tuple9('a', 'd', 'e', 'g', 'j', 'l', 'n', 'p', 'r'),
            Tuple9('a', 'd', 'e', 'h', 'i', 'k', 'm', 'o', 'q'),
            Tuple9('a', 'd', 'e', 'h', 'i', 'k', 'm', 'o', 'r'),
            Tuple9('a', 'd', 'e', 'h', 'i', 'k', 'm', 'p', 'q'),
            Tuple9('a', 'd', 'e', 'h', 'i', 'k', 'm', 'p', 'r'),
            Tuple9('a', 'd', 'e', 'h', 'i', 'k', 'n', 'o', 'q'),
            Tuple9('a', 'd', 'e', 'h', 'i', 'k', 'n', 'o', 'r'),
            Tuple9('a', 'd', 'e', 'h', 'i', 'k', 'n', 'p', 'q'),
            Tuple9('a', 'd', 'e', 'h', 'i', 'k', 'n', 'p', 'r'),
            Tuple9('a', 'd', 'e', 'h', 'i', 'l', 'm', 'o', 'q'),
            Tuple9('a', 'd', 'e', 'h', 'i', 'l', 'm', 'o', 'r'),
            Tuple9('a', 'd', 'e', 'h', 'i', 'l', 'm', 'p', 'q'),
            Tuple9('a', 'd', 'e', 'h', 'i', 'l', 'm', 'p', 'r'),
            Tuple9('a', 'd', 'e', 'h', 'i', 'l', 'n', 'o', 'q'),
            Tuple9('a', 'd', 'e', 'h', 'i', 'l', 'n', 'o', 'r'),
            Tuple9('a', 'd', 'e', 'h', 'i', 'l', 'n', 'p', 'q'),
            Tuple9('a', 'd', 'e', 'h', 'i', 'l', 'n', 'p', 'r'),
            Tuple9('a', 'd', 'e', 'h', 'j', 'k', 'm', 'o', 'q'),
            Tuple9('a', 'd', 'e', 'h', 'j', 'k', 'm', 'o', 'r'),
            Tuple9('a', 'd', 'e', 'h', 'j', 'k', 'm', 'p', 'q'),
            Tuple9('a', 'd', 'e', 'h', 'j', 'k', 'm', 'p', 'r'),
            Tuple9('a', 'd', 'e', 'h', 'j', 'k', 'n', 'o', 'q'),
            Tuple9('a', 'd', 'e', 'h', 'j', 'k', 'n', 'o', 'r'),
            Tuple9('a', 'd', 'e', 'h', 'j', 'k', 'n', 'p', 'q'),
            Tuple9('a', 'd', 'e', 'h', 'j', 'k', 'n', 'p', 'r'),
            Tuple9('a', 'd', 'e', 'h', 'j', 'l', 'm', 'o', 'q'),
            Tuple9('a', 'd', 'e', 'h', 'j', 'l', 'm', 'o', 'r'),
            Tuple9('a', 'd', 'e', 'h', 'j', 'l', 'm', 'p', 'q'),
            Tuple9('a', 'd', 'e', 'h', 'j', 'l', 'm', 'p', 'r'),
            Tuple9('a', 'd', 'e', 'h', 'j', 'l', 'n', 'o', 'q'),
            Tuple9('a', 'd', 'e', 'h', 'j', 'l', 'n', 'o', 'r'),
            Tuple9('a', 'd', 'e', 'h', 'j', 'l', 'n', 'p', 'q'),
            Tuple9('a', 'd', 'e', 'h', 'j', 'l', 'n', 'p', 'r'),
            Tuple9('a', 'd', 'f', 'g', 'i', 'k', 'm', 'o', 'q'),
            Tuple9('a', 'd', 'f', 'g', 'i', 'k', 'm', 'o', 'r'),
            Tuple9('a', 'd', 'f', 'g', 'i', 'k', 'm', 'p', 'q'),
            Tuple9('a', 'd', 'f', 'g', 'i', 'k', 'm', 'p', 'r'),
            Tuple9('a', 'd', 'f', 'g', 'i', 'k', 'n', 'o', 'q'),
            Tuple9('a', 'd', 'f', 'g', 'i', 'k', 'n', 'o', 'r'),
            Tuple9('a', 'd', 'f', 'g', 'i', 'k', 'n', 'p', 'q'),
            Tuple9('a', 'd', 'f', 'g', 'i', 'k', 'n', 'p', 'r'),
            Tuple9('a', 'd', 'f', 'g', 'i', 'l', 'm', 'o', 'q'),
            Tuple9('a', 'd', 'f', 'g', 'i', 'l', 'm', 'o', 'r'),
            Tuple9('a', 'd', 'f', 'g', 'i', 'l', 'm', 'p', 'q'),
            Tuple9('a', 'd', 'f', 'g', 'i', 'l', 'm', 'p', 'r'),
            Tuple9('a', 'd', 'f', 'g', 'i', 'l', 'n', 'o', 'q'),
            Tuple9('a', 'd', 'f', 'g', 'i', 'l', 'n', 'o', 'r'),
            Tuple9('a', 'd', 'f', 'g', 'i', 'l', 'n', 'p', 'q'),
            Tuple9('a', 'd', 'f', 'g', 'i', 'l', 'n', 'p', 'r'),
            Tuple9('a', 'd', 'f', 'g', 'j', 'k', 'm', 'o', 'q'),
            Tuple9('a', 'd', 'f', 'g', 'j', 'k', 'm', 'o', 'r'),
            Tuple9('a', 'd', 'f', 'g', 'j', 'k', 'm', 'p', 'q'),
            Tuple9('a', 'd', 'f', 'g', 'j', 'k', 'm', 'p', 'r'),
            Tuple9('a', 'd', 'f', 'g', 'j', 'k', 'n', 'o', 'q'),
            Tuple9('a', 'd', 'f', 'g', 'j', 'k', 'n', 'o', 'r'),
            Tuple9('a', 'd', 'f', 'g', 'j', 'k', 'n', 'p', 'q'),
            Tuple9('a', 'd', 'f', 'g', 'j', 'k', 'n', 'p', 'r'),
            Tuple9('a', 'd', 'f', 'g', 'j', 'l', 'm', 'o', 'q'),
            Tuple9('a', 'd', 'f', 'g', 'j', 'l', 'm', 'o', 'r'),
            Tuple9('a', 'd', 'f', 'g', 'j', 'l', 'm', 'p', 'q'),
            Tuple9('a', 'd', 'f', 'g', 'j', 'l', 'm', 'p', 'r'),
            Tuple9('a', 'd', 'f', 'g', 'j', 'l', 'n', 'o', 'q'),
            Tuple9('a', 'd', 'f', 'g', 'j', 'l', 'n', 'o', 'r'),
            Tuple9('a', 'd', 'f', 'g', 'j', 'l', 'n', 'p', 'q'),
            Tuple9('a', 'd', 'f', 'g', 'j', 'l', 'n', 'p', 'r'),
            Tuple9('a', 'd', 'f', 'h', 'i', 'k', 'm', 'o', 'q'),
            Tuple9('a', 'd', 'f', 'h', 'i', 'k', 'm', 'o', 'r'),
            Tuple9('a', 'd', 'f', 'h', 'i', 'k', 'm', 'p', 'q'),
            Tuple9('a', 'd', 'f', 'h', 'i', 'k', 'm', 'p', 'r'),
            Tuple9('a', 'd', 'f', 'h', 'i', 'k', 'n', 'o', 'q'),
            Tuple9('a', 'd', 'f', 'h', 'i', 'k', 'n', 'o', 'r'),
            Tuple9('a', 'd', 'f', 'h', 'i', 'k', 'n', 'p', 'q'),
            Tuple9('a', 'd', 'f', 'h', 'i', 'k', 'n', 'p', 'r'),
            Tuple9('a', 'd', 'f', 'h', 'i', 'l', 'm', 'o', 'q'),
            Tuple9('a', 'd', 'f', 'h', 'i', 'l', 'm', 'o', 'r'),
            Tuple9('a', 'd', 'f', 'h', 'i', 'l', 'm', 'p', 'q'),
            Tuple9('a', 'd', 'f', 'h', 'i', 'l', 'm', 'p', 'r'),
            Tuple9('a', 'd', 'f', 'h', 'i', 'l', 'n', 'o', 'q'),
            Tuple9('a', 'd', 'f', 'h', 'i', 'l', 'n', 'o', 'r'),
            Tuple9('a', 'd', 'f', 'h', 'i', 'l', 'n', 'p', 'q'),
            Tuple9('a', 'd', 'f', 'h', 'i', 'l', 'n', 'p', 'r'),
            Tuple9('a', 'd', 'f', 'h', 'j', 'k', 'm', 'o', 'q'),
            Tuple9('a', 'd', 'f', 'h', 'j', 'k', 'm', 'o', 'r'),
            Tuple9('a', 'd', 'f', 'h', 'j', 'k', 'm', 'p', 'q'),
            Tuple9('a', 'd', 'f', 'h', 'j', 'k', 'm', 'p', 'r'),
            Tuple9('a', 'd', 'f', 'h', 'j', 'k', 'n', 'o', 'q'),
            Tuple9('a', 'd', 'f', 'h', 'j', 'k', 'n', 'o', 'r'),
            Tuple9('a', 'd', 'f', 'h', 'j', 'k', 'n', 'p', 'q'),
            Tuple9('a', 'd', 'f', 'h', 'j', 'k', 'n', 'p', 'r'),
            Tuple9('a', 'd', 'f', 'h', 'j', 'l', 'm', 'o', 'q'),
            Tuple9('a', 'd', 'f', 'h', 'j', 'l', 'm', 'o', 'r'),
            Tuple9('a', 'd', 'f', 'h', 'j', 'l', 'm', 'p', 'q'),
            Tuple9('a', 'd', 'f', 'h', 'j', 'l', 'm', 'p', 'r'),
            Tuple9('a', 'd', 'f', 'h', 'j', 'l', 'n', 'o', 'q'),
            Tuple9('a', 'd', 'f', 'h', 'j', 'l', 'n', 'o', 'r'),
            Tuple9('a', 'd', 'f', 'h', 'j', 'l', 'n', 'p', 'q'),
            Tuple9('a', 'd', 'f', 'h', 'j', 'l', 'n', 'p', 'r'),
            Tuple9('b', 'c', 'e', 'g', 'i', 'k', 'm', 'o', 'q'),
            Tuple9('b', 'c', 'e', 'g', 'i', 'k', 'm', 'o', 'r'),
            Tuple9('b', 'c', 'e', 'g', 'i', 'k', 'm', 'p', 'q'),
            Tuple9('b', 'c', 'e', 'g', 'i', 'k', 'm', 'p', 'r'),
            Tuple9('b', 'c', 'e', 'g', 'i', 'k', 'n', 'o', 'q'),
            Tuple9('b', 'c', 'e', 'g', 'i', 'k', 'n', 'o', 'r'),
            Tuple9('b', 'c', 'e', 'g', 'i', 'k', 'n', 'p', 'q'),
            Tuple9('b', 'c', 'e', 'g', 'i', 'k', 'n', 'p', 'r'),
            Tuple9('b', 'c', 'e', 'g', 'i', 'l', 'm', 'o', 'q'),
            Tuple9('b', 'c', 'e', 'g', 'i', 'l', 'm', 'o', 'r'),
            Tuple9('b', 'c', 'e', 'g', 'i', 'l', 'm', 'p', 'q'),
            Tuple9('b', 'c', 'e', 'g', 'i', 'l', 'm', 'p', 'r'),
            Tuple9('b', 'c', 'e', 'g', 'i', 'l', 'n', 'o', 'q'),
            Tuple9('b', 'c', 'e', 'g', 'i', 'l', 'n', 'o', 'r'),
            Tuple9('b', 'c', 'e', 'g', 'i', 'l', 'n', 'p', 'q'),
            Tuple9('b', 'c', 'e', 'g', 'i', 'l', 'n', 'p', 'r'),
            Tuple9('b', 'c', 'e', 'g', 'j', 'k', 'm', 'o', 'q'),
            Tuple9('b', 'c', 'e', 'g', 'j', 'k', 'm', 'o', 'r'),
            Tuple9('b', 'c', 'e', 'g', 'j', 'k', 'm', 'p', 'q'),
            Tuple9('b', 'c', 'e', 'g', 'j', 'k', 'm', 'p', 'r'),
            Tuple9('b', 'c', 'e', 'g', 'j', 'k', 'n', 'o', 'q'),
            Tuple9('b', 'c', 'e', 'g', 'j', 'k', 'n', 'o', 'r'),
            Tuple9('b', 'c', 'e', 'g', 'j', 'k', 'n', 'p', 'q'),
            Tuple9('b', 'c', 'e', 'g', 'j', 'k', 'n', 'p', 'r'),
            Tuple9('b', 'c', 'e', 'g', 'j', 'l', 'm', 'o', 'q'),
            Tuple9('b', 'c', 'e', 'g', 'j', 'l', 'm', 'o', 'r'),
            Tuple9('b', 'c', 'e', 'g', 'j', 'l', 'm', 'p', 'q'),
            Tuple9('b', 'c', 'e', 'g', 'j', 'l', 'm', 'p', 'r'),
            Tuple9('b', 'c', 'e', 'g', 'j', 'l', 'n', 'o', 'q'),
            Tuple9('b', 'c', 'e', 'g', 'j', 'l', 'n', 'o', 'r'),
            Tuple9('b', 'c', 'e', 'g', 'j', 'l', 'n', 'p', 'q'),
            Tuple9('b', 'c', 'e', 'g', 'j', 'l', 'n', 'p', 'r'),
            Tuple9('b', 'c', 'e', 'h', 'i', 'k', 'm', 'o', 'q'),
            Tuple9('b', 'c', 'e', 'h', 'i', 'k', 'm', 'o', 'r'),
            Tuple9('b', 'c', 'e', 'h', 'i', 'k', 'm', 'p', 'q'),
            Tuple9('b', 'c', 'e', 'h', 'i', 'k', 'm', 'p', 'r'),
            Tuple9('b', 'c', 'e', 'h', 'i', 'k', 'n', 'o', 'q'),
            Tuple9('b', 'c', 'e', 'h', 'i', 'k', 'n', 'o', 'r'),
            Tuple9('b', 'c', 'e', 'h', 'i', 'k', 'n', 'p', 'q'),
            Tuple9('b', 'c', 'e', 'h', 'i', 'k', 'n', 'p', 'r'),
            Tuple9('b', 'c', 'e', 'h', 'i', 'l', 'm', 'o', 'q'),
            Tuple9('b', 'c', 'e', 'h', 'i', 'l', 'm', 'o', 'r'),
            Tuple9('b', 'c', 'e', 'h', 'i', 'l', 'm', 'p', 'q'),
            Tuple9('b', 'c', 'e', 'h', 'i', 'l', 'm', 'p', 'r'),
            Tuple9('b', 'c', 'e', 'h', 'i', 'l', 'n', 'o', 'q'),
            Tuple9('b', 'c', 'e', 'h', 'i', 'l', 'n', 'o', 'r'),
            Tuple9('b', 'c', 'e', 'h', 'i', 'l', 'n', 'p', 'q'),
            Tuple9('b', 'c', 'e', 'h', 'i', 'l', 'n', 'p', 'r'),
            Tuple9('b', 'c', 'e', 'h', 'j', 'k', 'm', 'o', 'q'),
            Tuple9('b', 'c', 'e', 'h', 'j', 'k', 'm', 'o', 'r'),
            Tuple9('b', 'c', 'e', 'h', 'j', 'k', 'm', 'p', 'q'),
            Tuple9('b', 'c', 'e', 'h', 'j', 'k', 'm', 'p', 'r'),
            Tuple9('b', 'c', 'e', 'h', 'j', 'k', 'n', 'o', 'q'),
            Tuple9('b', 'c', 'e', 'h', 'j', 'k', 'n', 'o', 'r'),
            Tuple9('b', 'c', 'e', 'h', 'j', 'k', 'n', 'p', 'q'),
            Tuple9('b', 'c', 'e', 'h', 'j', 'k', 'n', 'p', 'r'),
            Tuple9('b', 'c', 'e', 'h', 'j', 'l', 'm', 'o', 'q'),
            Tuple9('b', 'c', 'e', 'h', 'j', 'l', 'm', 'o', 'r'),
            Tuple9('b', 'c', 'e', 'h', 'j', 'l', 'm', 'p', 'q'),
            Tuple9('b', 'c', 'e', 'h', 'j', 'l', 'm', 'p', 'r'),
            Tuple9('b', 'c', 'e', 'h', 'j', 'l', 'n', 'o', 'q'),
            Tuple9('b', 'c', 'e', 'h', 'j', 'l', 'n', 'o', 'r'),
            Tuple9('b', 'c', 'e', 'h', 'j', 'l', 'n', 'p', 'q'),
            Tuple9('b', 'c', 'e', 'h', 'j', 'l', 'n', 'p', 'r'),
            Tuple9('b', 'c', 'f', 'g', 'i', 'k', 'm', 'o', 'q'),
            Tuple9('b', 'c', 'f', 'g', 'i', 'k', 'm', 'o', 'r'),
            Tuple9('b', 'c', 'f', 'g', 'i', 'k', 'm', 'p', 'q'),
            Tuple9('b', 'c', 'f', 'g', 'i', 'k', 'm', 'p', 'r'),
            Tuple9('b', 'c', 'f', 'g', 'i', 'k', 'n', 'o', 'q'),
            Tuple9('b', 'c', 'f', 'g', 'i', 'k', 'n', 'o', 'r'),
            Tuple9('b', 'c', 'f', 'g', 'i', 'k', 'n', 'p', 'q'),
            Tuple9('b', 'c', 'f', 'g', 'i', 'k', 'n', 'p', 'r'),
            Tuple9('b', 'c', 'f', 'g', 'i', 'l', 'm', 'o', 'q'),
            Tuple9('b', 'c', 'f', 'g', 'i', 'l', 'm', 'o', 'r'),
            Tuple9('b', 'c', 'f', 'g', 'i', 'l', 'm', 'p', 'q'),
            Tuple9('b', 'c', 'f', 'g', 'i', 'l', 'm', 'p', 'r'),
            Tuple9('b', 'c', 'f', 'g', 'i', 'l', 'n', 'o', 'q'),
            Tuple9('b', 'c', 'f', 'g', 'i', 'l', 'n', 'o', 'r'),
            Tuple9('b', 'c', 'f', 'g', 'i', 'l', 'n', 'p', 'q'),
            Tuple9('b', 'c', 'f', 'g', 'i', 'l', 'n', 'p', 'r'),
            Tuple9('b', 'c', 'f', 'g', 'j', 'k', 'm', 'o', 'q'),
            Tuple9('b', 'c', 'f', 'g', 'j', 'k', 'm', 'o', 'r'),
            Tuple9('b', 'c', 'f', 'g', 'j', 'k', 'm', 'p', 'q'),
            Tuple9('b', 'c', 'f', 'g', 'j', 'k', 'm', 'p', 'r'),
            Tuple9('b', 'c', 'f', 'g', 'j', 'k', 'n', 'o', 'q'),
            Tuple9('b', 'c', 'f', 'g', 'j', 'k', 'n', 'o', 'r'),
            Tuple9('b', 'c', 'f', 'g', 'j', 'k', 'n', 'p', 'q'),
            Tuple9('b', 'c', 'f', 'g', 'j', 'k', 'n', 'p', 'r'),
            Tuple9('b', 'c', 'f', 'g', 'j', 'l', 'm', 'o', 'q'),
            Tuple9('b', 'c', 'f', 'g', 'j', 'l', 'm', 'o', 'r'),
            Tuple9('b', 'c', 'f', 'g', 'j', 'l', 'm', 'p', 'q'),
            Tuple9('b', 'c', 'f', 'g', 'j', 'l', 'm', 'p', 'r'),
            Tuple9('b', 'c', 'f', 'g', 'j', 'l', 'n', 'o', 'q'),
            Tuple9('b', 'c', 'f', 'g', 'j', 'l', 'n', 'o', 'r'),
            Tuple9('b', 'c', 'f', 'g', 'j', 'l', 'n', 'p', 'q'),
            Tuple9('b', 'c', 'f', 'g', 'j', 'l', 'n', 'p', 'r'),
            Tuple9('b', 'c', 'f', 'h', 'i', 'k', 'm', 'o', 'q'),
            Tuple9('b', 'c', 'f', 'h', 'i', 'k', 'm', 'o', 'r'),
            Tuple9('b', 'c', 'f', 'h', 'i', 'k', 'm', 'p', 'q'),
            Tuple9('b', 'c', 'f', 'h', 'i', 'k', 'm', 'p', 'r'),
            Tuple9('b', 'c', 'f', 'h', 'i', 'k', 'n', 'o', 'q'),
            Tuple9('b', 'c', 'f', 'h', 'i', 'k', 'n', 'o', 'r'),
            Tuple9('b', 'c', 'f', 'h', 'i', 'k', 'n', 'p', 'q'),
            Tuple9('b', 'c', 'f', 'h', 'i', 'k', 'n', 'p', 'r'),
            Tuple9('b', 'c', 'f', 'h', 'i', 'l', 'm', 'o', 'q'),
            Tuple9('b', 'c', 'f', 'h', 'i', 'l', 'm', 'o', 'r'),
            Tuple9('b', 'c', 'f', 'h', 'i', 'l', 'm', 'p', 'q'),
            Tuple9('b', 'c', 'f', 'h', 'i', 'l', 'm', 'p', 'r'),
            Tuple9('b', 'c', 'f', 'h', 'i', 'l', 'n', 'o', 'q'),
            Tuple9('b', 'c', 'f', 'h', 'i', 'l', 'n', 'o', 'r'),
            Tuple9('b', 'c', 'f', 'h', 'i', 'l', 'n', 'p', 'q'),
            Tuple9('b', 'c', 'f', 'h', 'i', 'l', 'n', 'p', 'r'),
            Tuple9('b', 'c', 'f', 'h', 'j', 'k', 'm', 'o', 'q'),
            Tuple9('b', 'c', 'f', 'h', 'j', 'k', 'm', 'o', 'r'),
            Tuple9('b', 'c', 'f', 'h', 'j', 'k', 'm', 'p', 'q'),
            Tuple9('b', 'c', 'f', 'h', 'j', 'k', 'm', 'p', 'r'),
            Tuple9('b', 'c', 'f', 'h', 'j', 'k', 'n', 'o', 'q'),
            Tuple9('b', 'c', 'f', 'h', 'j', 'k', 'n', 'o', 'r'),
            Tuple9('b', 'c', 'f', 'h', 'j', 'k', 'n', 'p', 'q'),
            Tuple9('b', 'c', 'f', 'h', 'j', 'k', 'n', 'p', 'r'),
            Tuple9('b', 'c', 'f', 'h', 'j', 'l', 'm', 'o', 'q'),
            Tuple9('b', 'c', 'f', 'h', 'j', 'l', 'm', 'o', 'r'),
            Tuple9('b', 'c', 'f', 'h', 'j', 'l', 'm', 'p', 'q'),
            Tuple9('b', 'c', 'f', 'h', 'j', 'l', 'm', 'p', 'r'),
            Tuple9('b', 'c', 'f', 'h', 'j', 'l', 'n', 'o', 'q'),
            Tuple9('b', 'c', 'f', 'h', 'j', 'l', 'n', 'o', 'r'),
            Tuple9('b', 'c', 'f', 'h', 'j', 'l', 'n', 'p', 'q'),
            Tuple9('b', 'c', 'f', 'h', 'j', 'l', 'n', 'p', 'r'),
            Tuple9('b', 'd', 'e', 'g', 'i', 'k', 'm', 'o', 'q'),
            Tuple9('b', 'd', 'e', 'g', 'i', 'k', 'm', 'o', 'r'),
            Tuple9('b', 'd', 'e', 'g', 'i', 'k', 'm', 'p', 'q'),
            Tuple9('b', 'd', 'e', 'g', 'i', 'k', 'm', 'p', 'r'),
            Tuple9('b', 'd', 'e', 'g', 'i', 'k', 'n', 'o', 'q'),
            Tuple9('b', 'd', 'e', 'g', 'i', 'k', 'n', 'o', 'r'),
            Tuple9('b', 'd', 'e', 'g', 'i', 'k', 'n', 'p', 'q'),
            Tuple9('b', 'd', 'e', 'g', 'i', 'k', 'n', 'p', 'r'),
            Tuple9('b', 'd', 'e', 'g', 'i', 'l', 'm', 'o', 'q'),
            Tuple9('b', 'd', 'e', 'g', 'i', 'l', 'm', 'o', 'r'),
            Tuple9('b', 'd', 'e', 'g', 'i', 'l', 'm', 'p', 'q'),
            Tuple9('b', 'd', 'e', 'g', 'i', 'l', 'm', 'p', 'r'),
            Tuple9('b', 'd', 'e', 'g', 'i', 'l', 'n', 'o', 'q'),
            Tuple9('b', 'd', 'e', 'g', 'i', 'l', 'n', 'o', 'r'),
            Tuple9('b', 'd', 'e', 'g', 'i', 'l', 'n', 'p', 'q'),
            Tuple9('b', 'd', 'e', 'g', 'i', 'l', 'n', 'p', 'r'),
            Tuple9('b', 'd', 'e', 'g', 'j', 'k', 'm', 'o', 'q'),
            Tuple9('b', 'd', 'e', 'g', 'j', 'k', 'm', 'o', 'r'),
            Tuple9('b', 'd', 'e', 'g', 'j', 'k', 'm', 'p', 'q'),
            Tuple9('b', 'd', 'e', 'g', 'j', 'k', 'm', 'p', 'r'),
            Tuple9('b', 'd', 'e', 'g', 'j', 'k', 'n', 'o', 'q'),
            Tuple9('b', 'd', 'e', 'g', 'j', 'k', 'n', 'o', 'r'),
            Tuple9('b', 'd', 'e', 'g', 'j', 'k', 'n', 'p', 'q'),
            Tuple9('b', 'd', 'e', 'g', 'j', 'k', 'n', 'p', 'r'),
            Tuple9('b', 'd', 'e', 'g', 'j', 'l', 'm', 'o', 'q'),
            Tuple9('b', 'd', 'e', 'g', 'j', 'l', 'm', 'o', 'r'),
            Tuple9('b', 'd', 'e', 'g', 'j', 'l', 'm', 'p', 'q'),
            Tuple9('b', 'd', 'e', 'g', 'j', 'l', 'm', 'p', 'r'),
            Tuple9('b', 'd', 'e', 'g', 'j', 'l', 'n', 'o', 'q'),
            Tuple9('b', 'd', 'e', 'g', 'j', 'l', 'n', 'o', 'r'),
            Tuple9('b', 'd', 'e', 'g', 'j', 'l', 'n', 'p', 'q'),
            Tuple9('b', 'd', 'e', 'g', 'j', 'l', 'n', 'p', 'r'),
            Tuple9('b', 'd', 'e', 'h', 'i', 'k', 'm', 'o', 'q'),
            Tuple9('b', 'd', 'e', 'h', 'i', 'k', 'm', 'o', 'r'),
            Tuple9('b', 'd', 'e', 'h', 'i', 'k', 'm', 'p', 'q'),
            Tuple9('b', 'd', 'e', 'h', 'i', 'k', 'm', 'p', 'r'),
            Tuple9('b', 'd', 'e', 'h', 'i', 'k', 'n', 'o', 'q'),
            Tuple9('b', 'd', 'e', 'h', 'i', 'k', 'n', 'o', 'r'),
            Tuple9('b', 'd', 'e', 'h', 'i', 'k', 'n', 'p', 'q'),
            Tuple9('b', 'd', 'e', 'h', 'i', 'k', 'n', 'p', 'r'),
            Tuple9('b', 'd', 'e', 'h', 'i', 'l', 'm', 'o', 'q'),
            Tuple9('b', 'd', 'e', 'h', 'i', 'l', 'm', 'o', 'r'),
            Tuple9('b', 'd', 'e', 'h', 'i', 'l', 'm', 'p', 'q'),
            Tuple9('b', 'd', 'e', 'h', 'i', 'l', 'm', 'p', 'r'),
            Tuple9('b', 'd', 'e', 'h', 'i', 'l', 'n', 'o', 'q'),
            Tuple9('b', 'd', 'e', 'h', 'i', 'l', 'n', 'o', 'r'),
            Tuple9('b', 'd', 'e', 'h', 'i', 'l', 'n', 'p', 'q'),
            Tuple9('b', 'd', 'e', 'h', 'i', 'l', 'n', 'p', 'r'),
            Tuple9('b', 'd', 'e', 'h', 'j', 'k', 'm', 'o', 'q'),
            Tuple9('b', 'd', 'e', 'h', 'j', 'k', 'm', 'o', 'r'),
            Tuple9('b', 'd', 'e', 'h', 'j', 'k', 'm', 'p', 'q'),
            Tuple9('b', 'd', 'e', 'h', 'j', 'k', 'm', 'p', 'r'),
            Tuple9('b', 'd', 'e', 'h', 'j', 'k', 'n', 'o', 'q'),
            Tuple9('b', 'd', 'e', 'h', 'j', 'k', 'n', 'o', 'r'),
            Tuple9('b', 'd', 'e', 'h', 'j', 'k', 'n', 'p', 'q'),
            Tuple9('b', 'd', 'e', 'h', 'j', 'k', 'n', 'p', 'r'),
            Tuple9('b', 'd', 'e', 'h', 'j', 'l', 'm', 'o', 'q'),
            Tuple9('b', 'd', 'e', 'h', 'j', 'l', 'm', 'o', 'r'),
            Tuple9('b', 'd', 'e', 'h', 'j', 'l', 'm', 'p', 'q'),
            Tuple9('b', 'd', 'e', 'h', 'j', 'l', 'm', 'p', 'r'),
            Tuple9('b', 'd', 'e', 'h', 'j', 'l', 'n', 'o', 'q'),
            Tuple9('b', 'd', 'e', 'h', 'j', 'l', 'n', 'o', 'r'),
            Tuple9('b', 'd', 'e', 'h', 'j', 'l', 'n', 'p', 'q'),
            Tuple9('b', 'd', 'e', 'h', 'j', 'l', 'n', 'p', 'r'),
            Tuple9('b', 'd', 'f', 'g', 'i', 'k', 'm', 'o', 'q'),
            Tuple9('b', 'd', 'f', 'g', 'i', 'k', 'm', 'o', 'r'),
            Tuple9('b', 'd', 'f', 'g', 'i', 'k', 'm', 'p', 'q'),
            Tuple9('b', 'd', 'f', 'g', 'i', 'k', 'm', 'p', 'r'),
            Tuple9('b', 'd', 'f', 'g', 'i', 'k', 'n', 'o', 'q'),
            Tuple9('b', 'd', 'f', 'g', 'i', 'k', 'n', 'o', 'r'),
            Tuple9('b', 'd', 'f', 'g', 'i', 'k', 'n', 'p', 'q'),
            Tuple9('b', 'd', 'f', 'g', 'i', 'k', 'n', 'p', 'r'),
            Tuple9('b', 'd', 'f', 'g', 'i', 'l', 'm', 'o', 'q'),
            Tuple9('b', 'd', 'f', 'g', 'i', 'l', 'm', 'o', 'r'),
            Tuple9('b', 'd', 'f', 'g', 'i', 'l', 'm', 'p', 'q'),
            Tuple9('b', 'd', 'f', 'g', 'i', 'l', 'm', 'p', 'r'),
            Tuple9('b', 'd', 'f', 'g', 'i', 'l', 'n', 'o', 'q'),
            Tuple9('b', 'd', 'f', 'g', 'i', 'l', 'n', 'o', 'r'),
            Tuple9('b', 'd', 'f', 'g', 'i', 'l', 'n', 'p', 'q'),
            Tuple9('b', 'd', 'f', 'g', 'i', 'l', 'n', 'p', 'r'),
            Tuple9('b', 'd', 'f', 'g', 'j', 'k', 'm', 'o', 'q'),
            Tuple9('b', 'd', 'f', 'g', 'j', 'k', 'm', 'o', 'r'),
            Tuple9('b', 'd', 'f', 'g', 'j', 'k', 'm', 'p', 'q'),
            Tuple9('b', 'd', 'f', 'g', 'j', 'k', 'm', 'p', 'r'),
            Tuple9('b', 'd', 'f', 'g', 'j', 'k', 'n', 'o', 'q'),
            Tuple9('b', 'd', 'f', 'g', 'j', 'k', 'n', 'o', 'r'),
            Tuple9('b', 'd', 'f', 'g', 'j', 'k', 'n', 'p', 'q'),
            Tuple9('b', 'd', 'f', 'g', 'j', 'k', 'n', 'p', 'r'),
            Tuple9('b', 'd', 'f', 'g', 'j', 'l', 'm', 'o', 'q'),
            Tuple9('b', 'd', 'f', 'g', 'j', 'l', 'm', 'o', 'r'),
            Tuple9('b', 'd', 'f', 'g', 'j', 'l', 'm', 'p', 'q'),
            Tuple9('b', 'd', 'f', 'g', 'j', 'l', 'm', 'p', 'r'),
            Tuple9('b', 'd', 'f', 'g', 'j', 'l', 'n', 'o', 'q'),
            Tuple9('b', 'd', 'f', 'g', 'j', 'l', 'n', 'o', 'r'),
            Tuple9('b', 'd', 'f', 'g', 'j', 'l', 'n', 'p', 'q'),
            Tuple9('b', 'd', 'f', 'g', 'j', 'l', 'n', 'p', 'r'),
            Tuple9('b', 'd', 'f', 'h', 'i', 'k', 'm', 'o', 'q'),
            Tuple9('b', 'd', 'f', 'h', 'i', 'k', 'm', 'o', 'r'),
            Tuple9('b', 'd', 'f', 'h', 'i', 'k', 'm', 'p', 'q'),
            Tuple9('b', 'd', 'f', 'h', 'i', 'k', 'm', 'p', 'r'),
            Tuple9('b', 'd', 'f', 'h', 'i', 'k', 'n', 'o', 'q'),
            Tuple9('b', 'd', 'f', 'h', 'i', 'k', 'n', 'o', 'r'),
            Tuple9('b', 'd', 'f', 'h', 'i', 'k', 'n', 'p', 'q'),
            Tuple9('b', 'd', 'f', 'h', 'i', 'k', 'n', 'p', 'r'),
            Tuple9('b', 'd', 'f', 'h', 'i', 'l', 'm', 'o', 'q'),
            Tuple9('b', 'd', 'f', 'h', 'i', 'l', 'm', 'o', 'r'),
            Tuple9('b', 'd', 'f', 'h', 'i', 'l', 'm', 'p', 'q'),
            Tuple9('b', 'd', 'f', 'h', 'i', 'l', 'm', 'p', 'r'),
            Tuple9('b', 'd', 'f', 'h', 'i', 'l', 'n', 'o', 'q'),
            Tuple9('b', 'd', 'f', 'h', 'i', 'l', 'n', 'o', 'r'),
            Tuple9('b', 'd', 'f', 'h', 'i', 'l', 'n', 'p', 'q'),
            Tuple9('b', 'd', 'f', 'h', 'i', 'l', 'n', 'p', 'r'),
            Tuple9('b', 'd', 'f', 'h', 'j', 'k', 'm', 'o', 'q'),
            Tuple9('b', 'd', 'f', 'h', 'j', 'k', 'm', 'o', 'r'),
            Tuple9('b', 'd', 'f', 'h', 'j', 'k', 'm', 'p', 'q'),
            Tuple9('b', 'd', 'f', 'h', 'j', 'k', 'm', 'p', 'r'),
            Tuple9('b', 'd', 'f', 'h', 'j', 'k', 'n', 'o', 'q'),
            Tuple9('b', 'd', 'f', 'h', 'j', 'k', 'n', 'o', 'r'),
            Tuple9('b', 'd', 'f', 'h', 'j', 'k', 'n', 'p', 'q'),
            Tuple9('b', 'd', 'f', 'h', 'j', 'k', 'n', 'p', 'r'),
            Tuple9('b', 'd', 'f', 'h', 'j', 'l', 'm', 'o', 'q'),
            Tuple9('b', 'd', 'f', 'h', 'j', 'l', 'm', 'o', 'r'),
            Tuple9('b', 'd', 'f', 'h', 'j', 'l', 'm', 'p', 'q'),
            Tuple9('b', 'd', 'f', 'h', 'j', 'l', 'm', 'p', 'r'),
            Tuple9('b', 'd', 'f', 'h', 'j', 'l', 'n', 'o', 'q'),
            Tuple9('b', 'd', 'f', 'h', 'j', 'l', 'n', 'o', 'r'),
            Tuple9('b', 'd', 'f', 'h', 'j', 'l', 'n', 'p', 'q'),
            Tuple9('b', 'd', 'f', 'h', 'j', 'l', 'n', 'p', 'r'),
          ],
        ),
      );
    });
  });
}
